@@ -16,12 +16,9 @@
 
 """Classes for a resource that implements a binary file repository."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'ByteStorageResource',
-    ]
+    "ByteStorageResource",
+]
 
 from zope.interface import implementer
 from zope.publisher.interfaces import NotFound
@@ -44,13 +41,15 @@ class ByteStorageResource(HTTPResource):
                 # Read-only resources only support GET.
                 allow_string = "GET"
             elif self.request.method == "PUT":
-                type = self.request.headers['Content-Type']
+                type = self.request.headers["Content-Type"]
                 disposition, params = self._parseContentDispositionHeader(
-                    self.request.headers['Content-Disposition'])
+                    self.request.headers["Content-Disposition"]
+                )
                 cache_stream = self.request.bodyStream.getCacheStream()
                 representation = cache_stream.read()
-                return self.do_PUT(type, representation,
-                                   params.get('filename'))
+                return self.do_PUT(
+                    type, representation, params.get("filename")
+                )
             elif self.request.method == "DELETE":
                 return self.do_DELETE()
             else:
@@ -63,21 +62,21 @@ class ByteStorageResource(HTTPResource):
         """See `IByteStorageResource`."""
         media_type = self.getPreferredSupportedContentType()
         if media_type in [self.WADL_TYPE, self.DEPRECATED_WADL_TYPE]:
-            result = self.toWADL().encode("utf-8")
-            self.request.response.setHeader('Content-Type', media_type)
+            result = self.toWADL().encode()
+            self.request.response.setHeader("Content-Type", media_type)
             return result
         if not self.context.is_stored:
             # No stored document exists here yet.
             raise NotFound(self.context, self.context.filename, self.request)
-        self.request.response.setStatus(303) # See Other
-        self.request.response.setHeader('Location', self.context.alias_url)
+        self.request.response.setStatus(303)  # See Other
+        self.request.response.setHeader("Location", self.context.alias_url)
 
     def do_PUT(self, type, representation, filename):
         """See `IByteStorageResource`."""
         try:
             self.context.field.validate(representation)
         except ValidationError as e:
-            self.request.response.setStatus(400) # Bad Request
+            self.request.response.setStatus(400)  # Bad Request
             return str(e)
         self.context.createStored(type, representation, filename)
 
