@@ -2,10 +2,7 @@
 
 """Base classes for one-off HTTP operations."""
 
-from __future__ import absolute_import, print_function
-
 import simplejson
-import six
 
 from zope.component import getMultiAdapter, getUtility, queryMultiAdapter
 from zope.event import notify
@@ -13,36 +10,47 @@ from zope.interface import Attribute, implementer, providedBy
 from zope.interface.interfaces import IInterface
 from zope.schema import Field
 from zope.schema.interfaces import (
-    IField, RequiredMissing, ValidationError, WrongType)
+    IField,
+    RequiredMissing,
+    ValidationError,
+    WrongType,
+)
 from zope.security.proxy import isinstance as zope_isinstance
 
 from lazr.lifecycle.event import ObjectModifiedEvent
 from lazr.lifecycle.snapshot import Snapshot
 
 from lazr.restful.interfaces import (
-    ICollection, IFieldMarshaller, IResourceDELETEOperation,
-    IResourceGETOperation, IResourcePOSTOperation, IWebServiceConfiguration)
+    ICollection,
+    IFieldMarshaller,
+    IResourceDELETEOperation,
+    IResourceGETOperation,
+    IResourcePOSTOperation,
+    IWebServiceConfiguration,
+)
 from lazr.restful.interfaces import ICollectionField, IReference
 from lazr.restful.utils import is_total_size_link_active
 from lazr.restful._resource import (
-    BatchingResourceMixin, CollectionResource, ResourceJSONEncoder)
+    BatchingResourceMixin,
+    CollectionResource,
+    ResourceJSONEncoder,
+)
 
 
-__metaclass__ = type
 __all__ = [
-    'IObjectLink',
-    'ObjectLink',
-    'ResourceOperation',
-    'ResourceGETOperation',
-    'ResourceDELETEOperation',
-    'ResourcePOSTOperation'
+    "IObjectLink",
+    "ObjectLink",
+    "ResourceOperation",
+    "ResourceGETOperation",
+    "ResourceDELETEOperation",
+    "ResourcePOSTOperation",
 ]
 
 
 class ResourceOperation(BatchingResourceMixin):
     """A one-off operation associated with a resource."""
 
-    JSON_TYPE = 'application/json'
+    JSON_TYPE = "application/json"
     send_modification_event = False
 
     def __init__(self, context, request):
@@ -67,20 +75,21 @@ class ResourceOperation(BatchingResourceMixin):
             return None
         base = str(self.request.URL)
         query = navigator.getCleanQueryString()
-        if query != '':
-            query += '&'
-        return base + '?' + query + "ws.show=total_size"
+        if query != "":
+            query += "&"
+        return base + "?" + query + "ws.show=total_size"
 
     def __call__(self):
         values, errors = self.validate()
         if len(errors) > 0:
             self.request.response.setStatus(400)
-            self.request.response.setHeader('Content-type', 'text/plain')
+            self.request.response.setHeader("Content-type", "text/plain")
             return "\n".join(errors)
 
         if self.send_modification_event:
             snapshot = Snapshot(
-                self.context, providing=providedBy(self.context))
+                self.context, providing=providedBy(self.context)
+            )
 
         response = self.call(**values)
 
@@ -88,7 +97,8 @@ class ResourceOperation(BatchingResourceMixin):
             event = ObjectModifiedEvent(
                 object=self.context,
                 object_before_modification=snapshot,
-                edited_fields=None)
+                edited_fields=None,
+            )
             notify(event)
         return self.encodeResult(response)
 
@@ -100,8 +110,10 @@ class ResourceOperation(BatchingResourceMixin):
         responsible for setting the Content-Type header and the status
         code.
         """
-        if (self.request.response.getHeader('Content-Type') is not None
-            or self.request.response.getStatus() != 599):
+        if (
+            self.request.response.getHeader("Content-Type") is not None
+            or self.request.response.getStatus() != 599
+        ):
             # The operation took care of everything and just needs
             # this object served to the client.
             return result
@@ -116,23 +128,24 @@ class ResourceOperation(BatchingResourceMixin):
             if self.total_size_only:
                 result = resource.get_total_size(collection)
             else:
-                result = resource.batch() + '}'
+                result = resource.batch() + "}"
         elif self.should_batch(result):
             if self.total_size_only:
                 result = self.get_total_size(result)
             else:
-                result = self.batch(result, self.request) + '}'
+                result = self.batch(result, self.request) + "}"
         else:
             # Serialize the result to JSON. Any embedded entries will be
             # automatically serialized.
             try:
                 result = simplejson.dumps(result, cls=ResourceJSONEncoder)
             except TypeError:
-                raise TypeError("Could not serialize object %s to JSON." %
-                                result)
+                raise TypeError(
+                    "Could not serialize object %s to JSON." % result
+                )
 
         self.request.response.setStatus(200)
-        self.request.response.setHeader('Content-Type', self.JSON_TYPE)
+        self.request.response.setHeader("Content-Type", self.JSON_TYPE)
         return result
 
     def should_batch(self, result):
@@ -146,8 +159,7 @@ class ResourceOperation(BatchingResourceMixin):
             # has its response batched.
             return True
 
-        if zope_isinstance(
-                result, (bytes, six.text_type, dict, set, list, tuple)):
+        if zope_isinstance(result, (bytes, str, dict, set, list, tuple)):
             # Ordinary Python data structures generally are not
             # batched.
             return False
@@ -157,7 +169,7 @@ class ResourceOperation(BatchingResourceMixin):
             return False
 
         try:
-            iterator = iter(result)
+            iter(result)
             # Objects that have iterators but aren't ordinary data structures
             # tend to be result-set objects. Batch them.
             return True
@@ -184,24 +196,28 @@ class ResourceOperation(BatchingResourceMixin):
         for field in self.params:
             name = field.__name__
             field = field.bind(self.context)
-            if (self.request.get(name, missing) is missing
-                and not field.required):
+            if (
+                self.request.get(name, missing) is missing
+                and not field.required
+            ):
                 value = field.default
             else:
                 marshaller = getMultiAdapter(
-                    (field, self.request), IFieldMarshaller)
+                    (field, self.request), IFieldMarshaller
+                )
                 try:
                     value = marshaller.marshall_from_request(
-                        self.request.form.get(name))
+                        self.request.form.get(name)
+                    )
                 except ValueError as e:
-                    errors.append(u"%s: %s" % (name, e))
+                    errors.append("%s: %s" % (name, e))
                     continue
             try:
                 field.validate(value)
             except RequiredMissing:
-                errors.append(u"%s: Required input is missing." % name)
+                errors.append("%s: Required input is missing." % name)
             except ValidationError as e:
-                errors.append(u"%s: %s" % (name, e))
+                errors.append("%s: %s" % (name, e))
             else:
                 validated_values[name] = value
         return (validated_values, errors)
@@ -229,8 +245,9 @@ class ResourcePOSTOperation(ResourceOperation):
 class IObjectLink(IField):
     """Field containing a link to an object."""
 
-    schema = Attribute("schema",
-        u"The Interface of the Object on the other end of the link.")
+    schema = Attribute(
+        "schema", "The Interface of the Object on the other end of the link."
+    )
 
 
 @implementer(IObjectLink)
@@ -242,4 +259,4 @@ class ObjectLink(Field):
             raise WrongType
 
         self.schema = schema
-        super(ObjectLink, self).__init__(**kw)
+        super().__init__(**kw)
