@@ -2,14 +2,13 @@
 
 """Data model objects for the LAZR example web service."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
-__all__ = ['Cookbook',
-           'CookbookServiceRootResource',
-           'CookbookSet',
-           'CookbookWebServiceObject',
-           'WebServiceConfiguration']
+__all__ = [
+    "Cookbook",
+    "CookbookServiceRootResource",
+    "CookbookSet",
+    "CookbookWebServiceObject",
+    "WebServiceConfiguration",
+]
 
 from datetime import date
 
@@ -24,33 +23,48 @@ from zope.security.proxy import removeSecurityProxy
 from lazr.restful import directives, ServiceRootResource
 
 from lazr.restful.interfaces import (
-    IByteStorage, IEntry, IServiceRootResource, ITopLevelEntryLink,
-    IWebServiceConfiguration)
+    IByteStorage,
+    IEntry,
+    IServiceRootResource,
+    ITopLevelEntryLink,
+    IWebServiceConfiguration,
+)
 from lazr.restful.example.base.interfaces import (
-    AlreadyNew, Cuisine, ICookbook, ICookbookSet, IDish, IDishSet,
-    IFileManager, IRecipe, IRecipeSet, IHasGet, NameAlreadyTaken)
+    AlreadyNew,
+    Cuisine,
+    ICookbook,
+    ICookbookSet,
+    IDish,
+    IDishSet,
+    IFileManager,
+    IRecipe,
+    IRecipeSet,
+    IHasGet,
+    NameAlreadyTaken,
+)
 from lazr.restful.simple import BaseWebServiceConfiguration
 from lazr.restful.testing.webservice import WebServiceTestPublication
 from lazr.restful.utils import get_current_web_service_request
 
 
-#Entry classes.
+# Entry classes.
 class CookbookWebServiceObject:
     """A basic object published through the web service."""
 
 
 @implementer(IByteStorage, ILocation)
-class SimpleByteStorage(CookbookWebServiceObject,
-                        grokcore.component.MultiAdapter):
+class SimpleByteStorage(
+    CookbookWebServiceObject, grokcore.component.MultiAdapter
+):
     """A simple IByteStorage implementation"""
+
     grokcore.component.adapts(IEntry, IBytes)
     grokcore.component.provides(IByteStorage)
 
     def __init__(self, entry, field):
         self.entry = entry
         self.field = field
-        self.is_stored = getattr(
-            self.entry, field.__name__, None) is not None
+        self.is_stored = getattr(self.entry, field.__name__, None) is not None
         if self.is_stored:
             self.filename = getattr(self.entry, field.__name__).filename
             self.id = getattr(self.entry, field.__name__).id
@@ -72,16 +86,18 @@ class SimpleByteStorage(CookbookWebServiceObject,
         implementation, and 2) the ByteStorage implementation cannot
         change between versions.
         """
-        return 'http://cookbooks.dev/%s/filemanager/%s' % (
+        return "http://cookbooks.dev/%s/filemanager/%s" % (
             getUtility(IWebServiceConfiguration).active_versions[-1],
-            self.id)
+            self.id,
+        )
 
     def createStored(self, mediaType, representation, filename=None):
         self.representation = representation
         if filename is None:
             filename = self.field.__name__
         self.id = getUtility(IFileManager).put(
-            mediaType, representation, filename)
+            mediaType, representation, filename
+        )
         self.filename = filename
         setattr(self.entry, self.field.__name__, self)
 
@@ -93,8 +109,17 @@ class SimpleByteStorage(CookbookWebServiceObject,
 @implementer(ICookbook)
 class Cookbook(CookbookWebServiceObject):
     """An object representing a cookbook"""
-    def __init__(self, name, description, cuisine, copyright_date,
-                 last_printing=None, price=0, confirmed=False):
+
+    def __init__(
+        self,
+        name,
+        description,
+        cuisine,
+        copyright_date,
+        last_printing=None,
+        price=0,
+        confirmed=False,
+    ):
         self.name = name
         self.cuisine = cuisine
         self.description = description
@@ -116,8 +141,7 @@ class Cookbook(CookbookWebServiceObject):
 
     def get(self, name):
         """See `IHasGet`."""
-        match = [recipe for recipe in self.recipes
-                 if recipe.dish.name == name]
+        match = [recipe for recipe in self.recipes if recipe.dish.name == name]
         if len(match) > 0:
             return match[0]
         return None
@@ -135,7 +159,8 @@ class Cookbook(CookbookWebServiceObject):
         if self.name.find("The New ") == 0:
             raise AlreadyNew(
                 "The 'New' trick can't be used on this cookbook "
-                "because its name already starts with 'The New'.")
+                "because its name already starts with 'The New'."
+            )
         self.name = "The New " + self.name
 
     def find_recipe_for(self, dish):
@@ -151,14 +176,14 @@ class Cookbook(CookbookWebServiceObject):
 
     def replace_cover(self, cover):
         entry = getMultiAdapter(
-            (self, get_current_web_service_request()), IEntry)
-        storage = SimpleByteStorage(entry, ICookbook['cover'])
-        storage.createStored('application/octet-stream', cover, 'cover')
+            (self, get_current_web_service_request()), IEntry
+        )
+        storage = SimpleByteStorage(entry, ICookbook["cover"])
+        storage.createStored("application/octet-stream", cover, "cover")
 
 
 @implementer(IDish)
 class Dish(CookbookWebServiceObject):
-
     def __init__(self, name):
         self.name = name
         self.recipes = []
@@ -177,7 +202,6 @@ class Dish(CookbookWebServiceObject):
 
 @implementer(IRecipe)
 class Recipe(CookbookWebServiceObject):
-
     def __init__(self, id, cookbook, dish, instructions, private=False):
         self.id = id
         self.dish = dish
@@ -199,10 +223,12 @@ class Recipe(CookbookWebServiceObject):
     def delete(self):
         getUtility(IRecipeSet).removeRecipe(self)
 
+
 # Top-level objects.
 @implementer(ILocation)
-class CookbookTopLevelObject(CookbookWebServiceObject,
-                             grokcore.component.GlobalUtility):
+class CookbookTopLevelObject(
+    CookbookWebServiceObject, grokcore.component.GlobalUtility
+):
     """An object published at the top level of the web service."""
 
     @property
@@ -217,6 +243,7 @@ class CookbookTopLevelObject(CookbookWebServiceObject,
 @implementer(ITopLevelEntryLink)
 class FeaturedCookbookLink(CookbookTopLevelObject):
     """A link to the currently featured cookbook."""
+
     grokcore.component.provides(ITopLevelEntryLink)
 
     @property
@@ -232,6 +259,7 @@ class FeaturedCookbookLink(CookbookTopLevelObject):
 @implementer(ICookbookSet)
 class CookbookSet(CookbookTopLevelObject):
     """The set of all cookbooks."""
+
     grokcore.component.provides(ICookbookSet)
 
     __name__ = "cookbooks"
@@ -266,14 +294,23 @@ class CookbookSet(CookbookTopLevelObject):
                 cookbooks.append(cookbook)
         return cookbooks
 
-    def create(self, name, description, cuisine, copyright_date,
-               last_printing=None, price=0):
+    def create(
+        self,
+        name,
+        description,
+        cuisine,
+        copyright_date,
+        last_printing=None,
+        price=0,
+    ):
         for cookbook in self.cookbooks:
             if cookbook.name == name:
                 raise NameAlreadyTaken(
-                    'A cookbook called "%s" already exists.' % name)
-        cookbook = Cookbook(name, description, cuisine, copyright_date,
-                            last_printing, price)
+                    'A cookbook called "%s" already exists.' % name
+                )
+        cookbook = Cookbook(
+            name, description, cuisine, copyright_date, last_printing, price
+        )
         self.cookbooks.append(cookbook)
         return cookbook
 
@@ -281,6 +318,7 @@ class CookbookSet(CookbookTopLevelObject):
 @implementer(IDishSet)
 class DishSet(CookbookTopLevelObject):
     """The set of all dishes."""
+
     grokcore.component.provides(IDishSet)
 
     __name__ = "dishes"
@@ -303,6 +341,7 @@ class DishSet(CookbookTopLevelObject):
 @implementer(IRecipeSet)
 class RecipeSet(CookbookTopLevelObject):
     """The set of all recipes."""
+
     grokcore.component.provides(IRecipeSet)
 
     __name__ = "recipes"
@@ -338,22 +377,24 @@ def year(year):
     """Turn a year into a datetime.date object."""
     return date(year, 1, 1)
 
-C1 = Cookbook(u"Mastering the Art of French Cooking", "", Cuisine.FRANCAISE,
-              year(1961))
-C2 = Cookbook(u"The Joy of Cooking", "", Cuisine.GENERAL, year(1995),
-              price=20)
-C3 = Cookbook(u"James Beard's American Cookery", "", Cuisine.AMERICAN,
-              year(1972))
-C4 = Cookbook(u"Everyday Greens", "", Cuisine.VEGETARIAN, year(2003))
-C5 = Cookbook(u"I'm Just Here For The Food", "", Cuisine.GENERAL, year(2002))
-C6 = Cookbook(u"Cooking Without Recipes", "", Cuisine.GENERAL, year(1959))
-C7 = Cookbook(u"Construsions un repas", "", Cuisine.FRANCAISE, year(2007))
+
+C1 = Cookbook(
+    "Mastering the Art of French Cooking", "", Cuisine.FRANCAISE, year(1961)
+)
+C2 = Cookbook("The Joy of Cooking", "", Cuisine.GENERAL, year(1995), price=20)
+C3 = Cookbook(
+    "James Beard's American Cookery", "", Cuisine.AMERICAN, year(1972)
+)
+C4 = Cookbook("Everyday Greens", "", Cuisine.VEGETARIAN, year(2003))
+C5 = Cookbook("I'm Just Here For The Food", "", Cuisine.GENERAL, year(2002))
+C6 = Cookbook("Cooking Without Recipes", "", Cuisine.GENERAL, year(1959))
+C7 = Cookbook("Construsions un repas", "", Cuisine.FRANCAISE, year(2007))
 COOKBOOKS = [C1, C2, C3, C4, C5, C6, C7]
 
 D1 = Dish("Roast chicken")
-C1_D1 = Recipe(1, C1, D1, u"You can always judge...")
-C2_D1 = Recipe(2, C2, D1, u"Draw, singe, stuff, and truss...")
-C3_D1 = Recipe(3, C3, D1, u"A perfectly roasted chicken is...")
+C1_D1 = Recipe(1, C1, D1, "You can always judge...")
+C2_D1 = Recipe(2, C2, D1, "Draw, singe, stuff, and truss...")
+C3_D1 = Recipe(3, C3, D1, "A perfectly roasted chicken is...")
 
 D2 = Dish("Baked beans")
 C2_D2 = Recipe(4, C2, D2, "Preheat oven to...")
@@ -378,35 +419,37 @@ class CookbookServiceRootResource(ServiceRootResource):
     @property
     def top_level_names(self):
         """Access or create the list of top-level objects."""
-        return {'cookbooks': getUtility(ICookbookSet),
-                'dishes' : getUtility(IDishSet),
-                'recipes' : getUtility(IRecipeSet),
-                'filemanager': getUtility(IFileManager)}
+        return {
+            "cookbooks": getUtility(ICookbookSet),
+            "dishes": getUtility(IDishSet),
+            "recipes": getUtility(IRecipeSet),
+            "filemanager": getUtility(IFileManager),
+        }
 
     def get(self, name):
         """Traverse to a top-level object."""
         obj = self.top_level_names.get(name)
         return obj
 
-# Define the web service configuration.
 
+# Define the web service configuration.
 class WebServiceConfiguration(BaseWebServiceConfiguration):
     directives.publication_class(WebServiceTestPublication)
     caching_policy = [10000, 2]
-    code_revision = 'test.revision'
+    code_revision = "test.revision"
     default_batch_size = 5
-    hostname = 'cookbooks.dev'
+    hostname = "cookbooks.dev"
     match_batch_size = 50
-    active_versions = ['1.0', 'devel']
+    active_versions = ["1.0", "devel"]
     service_description = """<p>This is a web service.</p>
     <p>It's got resources!</p>"""
-    version_descriptions = { 'devel' : """<p>The unstable development
+    version_descriptions = {
+        "devel": """<p>The unstable development
     version.</p>
 
     <p>Don't use this unless you like changing things.</p>"""
-                             }
+    }
     last_version_with_mutator_named_operations = None
     first_version_with_total_size_link = None
     use_https = False
-    view_permission = 'lazr.restful.example.base.View'
-
+    view_permission = "lazr.restful.example.base.View"
