@@ -2,11 +2,8 @@
 
 """A simple security policy for the LAZR example web service."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'CookbookWebServiceSecurityPolicy',
+    "CookbookWebServiceSecurityPolicy",
 ]
 
 from zope.security.simplepolicies import PermissiveSecurityPolicy
@@ -30,4 +27,3 @@ class CookbookWebServiceSecurityPolicy(PermissiveSecurityPolicy):
             return False
         else:
             return True
-
