@@ -1,19 +1,19 @@
 """The RESTful service root."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'BelowRootAbsoluteURL',
-    'RootAbsoluteURL',
-    'WebServiceConfiguration',
-    'WSGIExampleWebServiceRootResource',
-    ]
+    "BelowRootAbsoluteURL",
+    "RootAbsoluteURL",
+    "WebServiceConfiguration",
+    "WSGIExampleWebServiceRootResource",
+]
 
 from zope.traversing.browser import AbsoluteURL
 
 from lazr.restful.example.wsgi.resources import (
-    IKeyValuePair, PairSet, KeyValuePair)
+    IKeyValuePair,
+    PairSet,
+    KeyValuePair,
+)
 from lazr.restful.wsgi import BaseWSGIWebServiceConfiguration
 from lazr.restful.simple import RootResource, RootResourceAbsoluteURL
 
@@ -35,21 +35,21 @@ class BelowRootAbsoluteURL(AbsoluteURL):
 
 
 class WebServiceConfiguration(BaseWSGIWebServiceConfiguration):
-    code_revision = '1'
-    active_versions = ['1.0']
+    code_revision = "1"
+    active_versions = ["1.0"]
     use_https = False
     last_version_with_mutator_named_operations = None
-    view_permission = 'zope.Public'
+    view_permission = "zope.Public"
 
 
 class WSGIExampleWebServiceRootResource(RootResource):
     """The root resource for the WSGI example web service."""
+
     def _build_top_level_objects(self):
         pairset = PairSet()
         pairset.pairs = [
             KeyValuePair(self, "foo", "bar"),
-            KeyValuePair(self, "1", "2")
-            ]
+            KeyValuePair(self, "1", "2"),
+        ]
         collections = dict(pairs=(IKeyValuePair, pairset))
         return collections, {}
-
