@@ -2,14 +2,11 @@
 
 """LAZR zope.schema.IField implementation."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'CollectionField',
-    'Reference',
-    'ReferenceChoice',
-    ]
+    "CollectionField",
+    "Reference",
+    "ReferenceChoice",
+]
 
 from zope.interface import implementer
 from zope.schema import Choice, Field, Object
@@ -17,12 +14,16 @@ from zope.schema.interfaces import IObject, SchemaNotProvided
 from zope.schema._field import AbstractCollection
 
 from lazr.restful.interfaces import (
-    ICollectionField, IReference, IReferenceChoice)
+    ICollectionField,
+    IReference,
+    IReferenceChoice,
+)
 
 
 @implementer(ICollectionField)
 class CollectionField(AbstractCollection):
     """A collection associated with an entry."""
+
     # We subclass AbstractCollection instead of List because List
     # has a _type of list, and we don't want to have to implement list
     # semantics for this class.
@@ -34,8 +35,8 @@ class CollectionField(AbstractCollection):
         for collections of things linked to an object, and these collections
         are managed through a dedicated API.
         """
-        kwargs.setdefault('readonly', True)
-        super(CollectionField, self).__init__(*args, **kwargs)
+        kwargs.setdefault("readonly", True)
+        super().__init__(*args, **kwargs)
 
 
 @implementer(IReference)
@@ -69,6 +70,6 @@ class ReferenceChoice(Choice):
         :param schema: What kind of object makes up the Choice's vocabulary.
                        The default is IObject.
         """
-        schema = kwargs.pop('schema', IObject)
+        schema = kwargs.pop("schema", IObject)
         self.schema = schema
-        super(ReferenceChoice, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
