@@ -2,13 +2,12 @@
 
 """Helpers for publishing Django model objects in lazr.restful services."""
 
-__metaclass__ = type
 __all__ = [
-    'DjangoLocation',
-    'DjangoWebServiceConfiguration',
-    'IDjangoLocation',
-    'ManagerSequencer',
-    ]
+    "DjangoLocation",
+    "DjangoWebServiceConfiguration",
+    "IDjangoLocation",
+    "ManagerSequencer",
+]
 
 import settings
 
@@ -21,19 +20,16 @@ from zope.schema import getFieldsInOrder
 from zope.traversing.browser.absoluteurl import AbsoluteURL
 
 import grokcore.component
-# Without this trickery, this module (called "django") will mask the
-# real Django modules. We could use "from __future__ import
-# absolute_import", but that would not work with Python 2.4.
-ObjectDoesNotExist = __import__(
-    'django.core.exceptions', {}).core.exceptions.ObjectDoesNotExist
-Manager = __import__(
-    'django.db.models.manager', {}).db.models.manager.Manager
+from django.core.exceptions import ObjectDoesNotExist
+from django.db.models.manager import Manager
 
-from lazr.restful import directives
-from lazr.restful.interfaces import (
-    IWebServiceClientRequest, IWebServiceConfiguration)
-from lazr.restful.error import NotFoundView
-from lazr.restful.simple import BaseWebServiceConfiguration
+from lazr.restful import directives  # noqa: E402
+from lazr.restful.interfaces import (  # noqa: E402
+    IWebServiceClientRequest,
+    IWebServiceConfiguration,
+)
+from lazr.restful.error import NotFoundView  # noqa: E402
+from lazr.restful.simple import BaseWebServiceConfiguration  # noqa: E402
 
 
 class DjangoWebServiceConfiguration(BaseWebServiceConfiguration):
@@ -50,7 +46,9 @@ class DjangoConfigurationGrokker(martian.ClassGrokker):
     Subclass DjangoWebServiceConfiguration to get a configuration class
     that can be overridden from your Django 'settings' module.
     """
+
     martian.component(DjangoWebServiceConfiguration)
+
     def execute(self, cls, config, *kw):
         for name, field in getFieldsInOrder(IWebServiceConfiguration):
             settings_name = "LAZR_RESTFUL_" + name.upper()
@@ -76,23 +74,28 @@ class IDjangoLocation(Interface):
     def __parent_object__(self):
         """This object's parent in the object tree."""
 
+
 # We want a raised django.core.exceptions.ObjectDoesNotExist
 # object to result in a 404 status code. But we don't
 # control that class definition, so we can't annotate it.
 # Instead, we define an adapter from that exception class to the
 # NotFoundView
 grokcore.component.global_adapter(
-    NotFoundView, (ObjectDoesNotExist, IWebServiceClientRequest),
-    Interface, name="index.html")
+    NotFoundView,
+    (ObjectDoesNotExist, IWebServiceClientRequest),
+    Interface,
+    name="index.html",
+)
 
 
 class DjangoAbsoluteURL(AbsoluteURL):
     """An AbsoluteURL implementation for Django."""
+
     directives.location_interface(IDjangoLocation)
 
 
 @implementer(ILocation)
-class DjangoLocation(object):
+class DjangoLocation:
     """Adapts Django model objects to ILocation.
 
     See `IDjangoLocation` for why Django model objects can't implement
@@ -109,11 +112,13 @@ class DjangoLocation(object):
     @property
     def __name__(self):
         return self.context.__url_path__
+
+
 grokcore.component.global_adapter(DjangoLocation, IDjangoLocation, ILocation)
 
 
 @implementer(IFiniteSequence)
-class ManagerSequencer(object):
+class ManagerSequencer:
     """Makes a Django manager object usable with lazr.batchnavigator.
 
     IFiniteSequence requires that we implement __len__, and either
@@ -135,4 +140,6 @@ class ManagerSequencer(object):
     def __len__(self):
         """Return the length of the dataset."""
         return self.manager.count()
+
+
 grokcore.component.global_adapter(ManagerSequencer, Manager, IFiniteSequence)
