@@ -18,45 +18,42 @@
 # Pylint doesn't grok zope interfaces.
 # pylint: disable-msg=E0211,E0213
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'IByteStorage',
-    'IByteStorageResource',
-    'ICollection',
-    'ICollectionResource',
-    'IEntry',
-    'IEntryField',
-    'IEntryFieldResource',
-    'IEntryResource',
-    'IFieldHTMLRenderer',
-    'IFieldMarshaller',
-    'IFileLibrarian',
-    'IHTTPResource',
-    'INotificationsProvider',
-    'IJSONPublishable',
-    'IJSONRequestCache',
-    'IRepresentationCache',
-    'IResourceOperation',
-    'IResourceGETOperation',
-    'IResourceDELETEOperation',
-    'IResourcePOSTOperation',
-    'IScopedCollection',
-    'IServiceRootResource',
-    'ITopLevelEntryLink',
-    'ITraverseWithGet',
-    'IUnmarshallingDoesntNeedValue',
-    'IWebServiceConfiguration',
-    'IWebBrowserInitiatedRequest',
-    'LAZR_WEBSERVICE_NAME',
-    'LAZR_WEBSERVICE_NS',
-    'IWebBrowserOriginatingRequest',
-    'IWebServiceClientRequest',
-    'IWebServiceExceptionView',
-    'IWebServiceLayer',
-    'IWebServiceVersion',
-    ]
+    "IByteStorage",
+    "IByteStorageResource",
+    "ICollection",
+    "ICollectionResource",
+    "IEntry",
+    "IEntryField",
+    "IEntryFieldResource",
+    "IEntryResource",
+    "IFieldHTMLRenderer",
+    "IFieldMarshaller",
+    "IFileLibrarian",
+    "IHTTPResource",
+    "INotificationsProvider",
+    "IJSONPublishable",
+    "IJSONRequestCache",
+    "IRepresentationCache",
+    "IResourceOperation",
+    "IResourceGETOperation",
+    "IResourceDELETEOperation",
+    "IResourcePOSTOperation",
+    "IScopedCollection",
+    "IServiceRootResource",
+    "ITopLevelEntryLink",
+    "ITraverseWithGet",
+    "IUnmarshallingDoesntNeedValue",
+    "IWebServiceConfiguration",
+    "IWebBrowserInitiatedRequest",
+    "LAZR_WEBSERVICE_NAME",
+    "LAZR_WEBSERVICE_NS",
+    "IWebBrowserOriginatingRequest",
+    "IWebServiceClientRequest",
+    "IWebServiceExceptionView",
+    "IWebServiceLayer",
+    "IWebServiceVersion",
+]
 
 from textwrap import dedent
 from zope.schema import (
@@ -66,11 +63,12 @@ from zope.schema import (
     List,
     Text,
     TextLine,
-    )
+)
 from zope.interface import (
     Attribute,
     Interface,
-    )
+)
+
 # These two should really be imported from zope.interface, but
 # the import fascist complains because they are not in __all__ there.
 from zope.interface.interface import invariant
@@ -79,18 +77,18 @@ from zope.publisher.interfaces import IPublishTraverse
 from zope.publisher.interfaces.browser import (
     IBrowserRequest,
     IDefaultBrowserLayer,
-    )
+)
 from lazr.batchnavigator.interfaces import InvalidBatchSizeError
 
 # Constants for periods of time
-HOUR = 3600 # seconds
+HOUR = 3600  # seconds
 
 # The namespace prefix for LAZR web service-related tags.
-LAZR_WEBSERVICE_NS = 'lazr.restful'
+LAZR_WEBSERVICE_NS = "lazr.restful"
 
 # The namespace for LAZR web service tags having to do with the names
 # of things.
-LAZR_WEBSERVICE_NAME = '%s.name' % LAZR_WEBSERVICE_NS
+LAZR_WEBSERVICE_NAME = "%s.name" % LAZR_WEBSERVICE_NS
 
 
 class IHTTPResource(Interface):
@@ -117,6 +115,7 @@ class IJSONPublishable(Interface):
         may include parameters.
         """
 
+
 class IServiceRootResource(IHTTPResource):
     """A service root object that also acts as a resource."""
 
@@ -181,7 +180,8 @@ class IResourceOperation(Interface):
         """
 
     send_modification_event = Attribute(
-        "Whether or not to send out an event when this operation completes.")
+        "Whether or not to send out an event when this operation completes."
+    )
 
 
 class IResourceGETOperation(IResourceOperation):
@@ -189,8 +189,10 @@ class IResourceGETOperation(IResourceOperation):
 
     This might be a search or lookup operation.
     """
+
     return_type = Attribute(
-        "The type of the resource returned by this operation, if any.")
+        "The type of the resource returned by this operation, if any."
+    )
 
 
 class IResourceDELETEOperation(IResourceOperation):
@@ -210,16 +212,16 @@ class IResourcePOSTOperation(IResourceOperation):
 class IEntry(Interface):
     """An entry, exposed as a resource by an IEntryResource."""
 
-    schema = Attribute(
-        'The schema describing the data fields on this entry.')
+    schema = Attribute("The schema describing the data fields on this entry.")
 
     @invariant
     def schemaIsProvided(value):
         """Make sure that the entry also provides its schema."""
         if not value.schema.providedBy(value):
             raise Invalid(
-                "%s doesn't provide its %s schema." % (
-                    type(value).__name__, value.schema.__name__))
+                "%s doesn't provide its %s schema."
+                % (type(value).__name__, value.schema.__name__)
+            )
 
 
 class ICollection(Interface):
@@ -236,8 +238,9 @@ class ICollection(Interface):
 
 class IScopedCollection(ICollection):
 
-    relationship = Attribute("The relationship between an entry and a "
-                             "collection.")
+    relationship = Attribute(
+        "The relationship between an entry and a " "collection."
+    )
     collection = Attribute("The collection scoped to an entry.")
 
 
@@ -275,12 +278,15 @@ class ITopLevelEntryLink(Interface):
     resource.
     """
 
-    link_name = Attribute("The name of the link to this entry in the "
-                          "representation of the service root resource. "
-                          "'_link' will be automatically appended.")
+    link_name = Attribute(
+        "The name of the link to this entry in the "
+        "representation of the service root resource. "
+        "'_link' will be automatically appended."
+    )
 
-    entry_type = Attribute("The interface defined by the entry on the "
-                           "other end of the link.")
+    entry_type = Attribute(
+        "The interface defined by the entry on the " "other end of the link."
+    )
 
 
 class IWebBrowserOriginatingRequest(Interface):
@@ -298,7 +304,10 @@ class INotificationsProvider(Interface):
     A web framework may define an adapter for this interface, allowing
     the web service to provide notifications to be sent to the client.
     """
-    notifications = Attribute(dedent("""\
+
+    notifications = Attribute(
+        dedent(
+            """\
         A list of namedtuples (level, message) which can be used by the
         caller to display extra information about the completed request.
         'level' matches the standard logging levels:
@@ -307,12 +316,17 @@ class INotificationsProvider(Interface):
         INFO = logging.INFO       # simple confirmation of a change
         WARNING = logging.WARNING # action will not be successful unless...
         ERROR = logging.ERROR     # the previous action did not succeed
-        """))
+        """
+        )
+    )
+
 
 class IWebServiceClientRequest(IBrowserRequest):
     """Interface for requests to the web service."""
-    version = Attribute("The version of the web service that the client "
-                        "requested.")
+
+    version = Attribute(
+        "The version of the web service that the client " "requested."
+    )
 
 
 class IWebServiceLayer(IWebServiceClientRequest, IDefaultBrowserLayer):
@@ -329,14 +343,17 @@ class IWebServiceVersion(Interface):
     registerUtility(IWebServiceClientRequestBeta,
                     IWebServiceVersion, name="beta")
     """
+
     pass
 
+
 class IJSONRequestCache(Interface):
     """A cache of objects exposed as URLs or JSON representations."""
 
     links = Attribute("Objects whose links need to be exposed.")
-    objects = Attribute("Objects whose JSON representations need "
-                        "to be exposed.")
+    objects = Attribute(
+        "Objects whose JSON representations need " "to be exposed."
+    )
 
 
 class IByteStorage(Interface):
@@ -348,8 +365,10 @@ class IByteStorage(Interface):
 
     alias_url = Attribute("The external URL to the byte stream.")
     filename = Attribute("Filename for the byte stream.")
-    is_stored = Attribute("Whether or not there's a previously created "
-                          "external byte stream here.")
+    is_stored = Attribute(
+        "Whether or not there's a previously created "
+        "external byte stream here."
+    )
 
     def createStored(mediaType, representation, filename=None):
         """Create a new stored bytestream.
@@ -398,7 +417,8 @@ class IFieldMarshaller(Interface):
     """A mapper between schema fields and their representation on the wire."""
 
     representation_name = Attribute(
-        'The name to use for this field within the representation.')
+        "The name to use for this field within the representation."
+    )
 
     def marshall_from_json_data(value):
         """Transform the given data value into an object.
@@ -452,77 +472,87 @@ class IWebServiceConfiguration(Interface):
     These are miscellaneous strings that may differ in different web
     services.
     """
+
     caching_policy = List(
         value_type=Int(),
-        default = [7 * 24 * HOUR, 1 * HOUR],
-        title=u"The web service caching policy.",
-        description = u"""A list of two numbers, each to be used in the
+        default=[7 * 24 * HOUR, 1 * HOUR],
+        title="The web service caching policy.",
+        description="""A list of two numbers, each to be used in the
         'max-age' field of the Cache-Control header. The first number is
         used when serving the service root for any web service version
         except the latest one. The second number is used when serving the
         service root for the latest version (which probably changes more
-        often).""")
+        often).""",
+    )
 
     enable_server_side_representation_cache = Bool(
-        title=u"Enable the server-side representation cache.",
+        title="Enable the server-side representation cache.",
         default=True,
-        description=u"""If this is false, the server-side representation
-        cache will not be used, even if one is registered."""
-        )
+        description="""If this is false, the server-side representation
+        cache will not be used, even if one is registered.""",
+    )
 
     service_description = TextLine(
-        title=u"Service description",
-        description=u"""A human-readable description of the web service.
+        title="Service description",
+        description="""A human-readable description of the web service.
 
         The description may contain HTML, but if it does, it must be a
         valid XHTML fragment.
         """,
-        default=u"",
-        )
+        default="",
+    )
 
     view_permission = TextLine(
-        title=u"View permission", default=u"zope.View",
-        description=u"The permission to use when checking object visibility.")
+        title="View permission",
+        default="zope.View",
+        description="The permission to use when checking object visibility.",
+    )
 
     path_override = TextLine(
-        title=u"Web service path override", default=u"api",
-        description=u"The path component for Ajax clients to use when making "
+        title="Web service path override",
+        default="api",
+        description="The path component for Ajax clients to use when making "
         "HTTP requests to the web service from their current virtual host. "
         "The use of this path component (/api/foo instead of /foo) will "
         "ensure that the request is processed as a web service request "
-        "instead of a website request.")
+        "instead of a website request.",
+    )
 
     use_https = Bool(
-        title=u"Web service is secured",
+        title="Web service is secured",
         default=True,
-        description=u"Whether or not requests to the web service are secured "
-        "through SSL.")
+        description="Whether or not requests to the web service are secured "
+        "through SSL.",
+    )
 
     hostname = TextLine(
-        title=u"The hostname to be used in generated URLs.",
-        description=u"You only need to specify this if you're using the "
+        title="The hostname to be used in generated URLs.",
+        description="You only need to specify this if you're using the "
         "RootResourceAbsoluteURL class from lazr.restful.simple. This is "
-        "the hostname of the lazr.restful application.")
+        "the hostname of the lazr.restful application.",
+    )
 
     port = Int(
-        title=u"The TCP port on which the web service is running.",
-        description=u"Used in generated URLs.",
-        default=0)
+        title="The TCP port on which the web service is running.",
+        description="Used in generated URLs.",
+        default=0,
+    )
 
     service_root_uri_prefix = TextLine(
-        title=u"Any URL prefix necessary for the service root.",
-        default=u"",
-        description=u"If your web service is not located at the root of "
+        title="Any URL prefix necessary for the service root.",
+        default="",
+        description="If your web service is not located at the root of "
         "its domain (for instance, it's rooted at "
         "http://foo.com/web-service/ instead of http://api.foo/com/, "
         "put the URL prefix here. (In the example case, the URL prefix "
-        "is 'web-service/').")
+        "is 'web-service/').",
+    )
 
     active_versions = List(
         value_type=TextLine(),
-        default = [],
-        title=u"The active versions of the web service.",
-        description = u"""A list of names of active versions of this
+        default=[],
+        title="The active versions of the web service.",
+        description="""A list of names of active versions of this
         web service. They might be version numbers, names such as
         "beta", or the date a particular version was finalized.
 
@@ -532,13 +562,14 @@ class IWebServiceConfiguration(Interface):
         something like 'trunk' or 'devel': effectively an alias for
         "the most up-to-date code".
 
-        This list must contain at least one version name.""")
+        This list must contain at least one version name.""",
+    )
 
     version_descriptions = Dict(
-        key_type = TextLine(),
-        value_type = Text(),
-        title = u"Human-readable descriptions of the web service versions.",
-        description = u"""A dictionary mapping version names to
+        key_type=TextLine(),
+        value_type=Text(),
+        title="Human-readable descriptions of the web service versions.",
+        description="""A dictionary mapping version names to
         human-readable descriptions. The descriptions should describe
         what distinguishes this version from other versions, and
         mention if/when the version will be removed.
@@ -546,19 +577,20 @@ class IWebServiceConfiguration(Interface):
         The descriptions may contain HTML, but if they do, they must be
         valid XHTML fragments.
         """,
-        default = {}
-        )
+        default={},
+    )
 
     require_explicit_versions = Bool(
         default=False,
-        description=u"""If true, each exported field and named
+        description="""If true, each exported field and named
         operation must explicitly declare the first version in which
         it appears. If false, fields and operations are published in
-        all versions.""")
+        all versions.""",
+    )
 
     last_version_with_mutator_named_operations = TextLine(
         default=None,
-        description=u"""In earlier versions of lazr.restful, mutator methods
+        description="""In earlier versions of lazr.restful, mutator methods
         were also published as named operations. This redundant
         behavior is no longer enabled by default, but this setting
         allows for backwards compatibility.
@@ -566,48 +598,53 @@ class IWebServiceConfiguration(Interface):
         Mutator methods will also be published as named operations in
         the version you specify here, and in any previous versions. In
         all subsequent versions, they will not be published as named
-        operations.""")
+        operations.""",
+    )
 
     first_version_with_total_size_link = TextLine(
         default=None,
-        description=u"""In earlier versions of lazr.restful collections
+        description="""In earlier versions of lazr.restful collections
         included a total_size field, now they include a total_size_link
         instead. Setting this value determines in which version the new
-        behavior takes effect.""")
+        behavior takes effect.""",
+    )
 
     code_revision = TextLine(
-        default=u"",
-        description=u"""A string designating the current revision
+        default="",
+        description="""A string designating the current revision
         number of the code running the webservice. This may be a
         revision number from version control, or a hand-chosen version
-        number.""")
+        number.""",
+    )
 
     show_tracebacks = Bool(
-        title=u"Show tracebacks to end-users",
+        title="Show tracebacks to end-users",
         default=True,
-        description=u"Whether or not to show tracebacks in an HTTP response "
-        "for a request that raised an exception.")
+        description="Whether or not to show tracebacks in an HTTP response "
+        "for a request that raised an exception.",
+    )
 
     default_batch_size = Int(
-        title=u"The default batch size to use when serving a collection",
+        title="The default batch size to use when serving a collection",
         default=50,
-        description=u"When the client requests a collection and doesn't "
+        description="When the client requests a collection and doesn't "
         "specify how many entries they want, this many entries will be "
-        "served them in the first page.")
+        "served them in the first page.",
+    )
 
     max_batch_size = Int(
-        title=u"The maximum batch size",
+        title="The maximum batch size",
         default=300,
-        description=u"When the client requests a batch of entries from "
+        description="When the client requests a batch of entries from "
         "a collection, they will not be allowed to request more entries "
-        "in the batch than this.")
+        "in the batch than this.",
+    )
 
     compensate_for_mod_compress_etag_modification = Bool(
-        title=u"Accept incoming ETags that appear to have been modified "
-               "in transit by Apache's mod_compress.",
+        title="Accept incoming ETags that appear to have been modified "
+        "in transit by Apache's mod_compress.",
         default=False,
-
-        description=u"""When mod_compress compresses an outgoing
+        description="""When mod_compress compresses an outgoing
         representation, it (correctly) modifies the ETag. But when
         that ETag comes back in on a conditional GET or PUT request,
         mod_compress does _not_ transparently remove the modification,
@@ -633,7 +670,8 @@ class IWebServiceConfiguration(Interface):
         layers of HTTP intermediary. (An earlier attempt to use
         transfer-encoding instead of content-encoding failed because
         HTTP intermediaries strip the TE header.)
-        """)
+        """,
+    )
 
     def createRequest(body_instream, environ):
         """A factory method that creates a request for the web service.
