@@ -2,46 +2,42 @@
 
 """Marshallers for fields used in HTTP resources."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'AbstractCollectionFieldMarshaller',
-    'BoolFieldMarshaller',
-    'BytesFieldMarshaller',
-    'CollectionFieldMarshaller',
-    'DateTimeFieldMarshaller',
-    'DictFieldMarshaller',
-    'FloatFieldMarshaller',
-    'IntFieldMarshaller',
-    'ObjectLookupFieldMarshaller',
-    'SetFieldMarshaller',
-    'SimpleFieldMarshaller',
-    'SimpleVocabularyLookupFieldMarshaller',
-    'TextFieldMarshaller',
-    'TokenizedVocabularyFieldMarshaller',
-    'URLDereferencingMixin',
-    'VocabularyLookupFieldMarshaller',
-    ]
+    "AbstractCollectionFieldMarshaller",
+    "BoolFieldMarshaller",
+    "BytesFieldMarshaller",
+    "CollectionFieldMarshaller",
+    "DateTimeFieldMarshaller",
+    "DictFieldMarshaller",
+    "FloatFieldMarshaller",
+    "IntFieldMarshaller",
+    "ObjectLookupFieldMarshaller",
+    "SetFieldMarshaller",
+    "SimpleFieldMarshaller",
+    "SimpleVocabularyLookupFieldMarshaller",
+    "TextFieldMarshaller",
+    "TokenizedVocabularyFieldMarshaller",
+    "URLDereferencingMixin",
+    "VocabularyLookupFieldMarshaller",
+]
 
 from collections import OrderedDict
 from datetime import datetime
 from io import BytesIO
 import re
+from urllib.parse import unquote
 
 import pytz
 import simplejson
-import six
-from six.moves.urllib.parse import unquote
 
 from zope.datetime import (
     DateTimeError,
     DateTimeParser,
-    )
+)
 from zope.component import (
     getMultiAdapter,
     getUtility,
-    )
+)
 from zope.interface import implementer
 from zope.publisher.interfaces import NotFound
 from zope.schema import Field
@@ -51,15 +47,14 @@ from zope.traversing.browser import absoluteURL
 from lazr.uri import (
     URI,
     InvalidURIError,
-    )
+)
 
 from lazr.restful.interfaces import (
     IFieldMarshaller,
     IUnmarshallingDoesntNeedValue,
     IServiceRootResource,
     IWebServiceConfiguration,
-    )
-from lazr.restful.utils import safe_hasattr
+)
 
 
 class URLDereferencingMixin:
@@ -80,22 +75,23 @@ class URLDereferencingMixin:
         """
         config = getUtility(IWebServiceConfiguration)
         if config.use_https:
-            site_protocol = 'https'
-            default_port = '443'
+            site_protocol = "https"
+            default_port = "443"
         else:
-            site_protocol = 'http'
-            default_port = '80'
-        full_request_host = self.request.get('HTTP_HOST', 'localhost')
-        if ':' in full_request_host:
-            request_host, request_port = full_request_host.split(':', 2)
+            site_protocol = "http"
+            default_port = "80"
+        full_request_host = self.request.get("HTTP_HOST", "localhost")
+        if ":" in full_request_host:
+            request_host, request_port = full_request_host.split(":", 2)
         else:
             request_host = full_request_host
             request_port = default_port
 
-        if not isinstance(url, six.string_types):
-            raise ValueError(u"got '%s', expected string: %r" % (
-                type(url).__name__, url))
-        if url.startswith('/'):
+        if not isinstance(url, str):
+            raise ValueError(
+                "got '%s', expected string: %r" % (type(url).__name__, url)
+            )
+        if url.startswith("/"):
             # It's a relative URI. Resolve it relative to the root of this
             # version of the web service.
             service_root = getUtility(IServiceRootResource)
@@ -111,22 +107,28 @@ class URLDereferencingMixin:
         fragment = uri.fragment
 
         url_host_and_http_host_are_identical = (
-            host == request_host and port == request_port)
-        if (not url_host_and_http_host_are_identical
-            or protocol != site_protocol or query is not None
-            or fragment is not None):
+            host == request_host and port == request_port
+        )
+        if (
+            not url_host_and_http_host_are_identical
+            or protocol != site_protocol
+            or query is not None
+            or fragment is not None
+        ):
             raise NotFound(self, url, self.request)
 
-        path_parts = [unquote(part) for part in path.split('/')]
+        path_parts = [unquote(part) for part in path.split("/")]
         path_parts.pop(0)
         path_parts.reverse()
-        environ = {'PATH_INFO': path, 'HTTP_HOST': full_request_host}
-        server_url = self.request.get('SERVER_URL')
+        environ = {"PATH_INFO": path, "HTTP_HOST": full_request_host}
+        server_url = self.request.get("SERVER_URL")
         if server_url is not None:
-            environ['SERVER_URL'] = server_url
+            environ["SERVER_URL"] = server_url
         else:
-            environ['SERVER_URL'] = '%s://%s' % (
-                site_protocol, full_request_host)
+            environ["SERVER_URL"] = "%s://%s" % (
+                site_protocol,
+                full_request_host,
+            )
         request = config.createRequest(BytesIO(), environ)
         request.setTraversalStack(path_parts)
         root = request.publication.getApplication(self.request)
@@ -138,9 +140,9 @@ class URLDereferencingMixin:
             resource = self.dereference_url(url)
         except NotFound:
             # The URL doesn't correspond to any real object.
-            raise ValueError(u'No such object "%s".' % url)
+            raise ValueError('No such object "%s".' % url)
         except InvalidURIError:
-            raise ValueError(u'"%s" is not a valid URI.' % url)
+            raise ValueError('"%s" is not a valid URI.' % url)
         # We looked up the URL and got the thing at the other end of
         # the URL: a resource. But internally, a resource isn't a
         # valid value for any schema field. Instead we want the object
@@ -181,13 +183,13 @@ class SimpleFieldMarshaller:
         _marshall_from_request() if it's not None. If value isn't a
         JSON-encoded string, interpret it as string literal.
         """
-        if value != '':
+        if value != "":
             try:
                 v = value
                 if isinstance(v, bytes):
-                    v = v.decode('utf8') # assume utf8
-                elif not isinstance(v, six.text_type):
-                    v = six.text_type(v)
+                    v = v.decode("utf8")  # assume utf8
+                elif not isinstance(v, str):
+                    v = str(v)
                 value = simplejson.loads(v)
             except (ValueError, TypeError):
                 # Pass the value as is. This saves client from having to encode
@@ -213,12 +215,14 @@ class SimpleFieldMarshaller:
             if not isinstance(value, self._type):
                 if isinstance(self._type, (tuple, list)):
                     expected_name = ", ".join(
-                        a_type.__name__ for a_type in self._type)
+                        a_type.__name__ for a_type in self._type
+                    )
                 else:
                     expected_name = self._type.__name__
                 raise ValueError(
-                    u"got '%s', expected %s: %r" % (
-                        type(value).__name__, expected_name, value))
+                    "got '%s', expected %s: %r"
+                    % (type(value).__name__, expected_name, value)
+                )
         return value
 
     @property
@@ -266,15 +270,14 @@ class FloatFieldMarshaller(SimpleFieldMarshaller):
 
         Converts the value to a float.
         """
-        return float(
-            super(FloatFieldMarshaller, self)._marshall_from_json_data(value))
+        return float(super()._marshall_from_json_data(value))
 
 
 class BytesFieldMarshaller(SimpleFieldMarshaller):
     """FieldMarshaller for IBytes field."""
 
     _type = bytes
-    _type_error_message = 'not a string: %r'
+    _type_error_message = "not a string: %r"
 
     @property
     def representation_name(self):
@@ -289,8 +292,10 @@ class BytesFieldMarshaller(SimpleFieldMarshaller):
 
         Marshall as a link to the byte storage resource.
         """
-        return "%s/%s" % (absoluteURL(entry.context, self.request),
-                          self.field.__name__)
+        return "%s/%s" % (
+            absoluteURL(entry.context, self.request),
+            self.field.__name__,
+        )
 
     def marshall_from_request(self, value):
         """See `IFieldMarshaller`.
@@ -304,11 +309,11 @@ class BytesFieldMarshaller(SimpleFieldMarshaller):
         """
         if value is None:
             return None
-        if safe_hasattr(value, 'seek'):
+        if hasattr(value, "seek"):
             value.seek(0)
             value = value.read()
-        elif not isinstance(value, (bytes, six.text_type)):
-            value = str(value).encode('UTF-8')
+        elif not isinstance(value, (bytes, str)):
+            value = str(value).encode()
         else:
             # Leave string conversion to _marshall_from_json_data.
             pass
@@ -319,29 +324,28 @@ class BytesFieldMarshaller(SimpleFieldMarshaller):
 
         Convert all strings to byte strings.
         """
-        if isinstance(value, six.text_type):
-            value = value.encode('utf-8')
-        return super(
-            BytesFieldMarshaller, self)._marshall_from_json_data(value)
+        if isinstance(value, str):
+            value = value.encode()
+        return super()._marshall_from_json_data(value)
 
 
 class TextFieldMarshaller(SimpleFieldMarshaller):
     """FieldMarshaller for IText fields."""
 
-    _type = six.text_type
-    _type_error_message = 'not a unicode string: %r'
+    _type = str
+    _type_error_message = "not a unicode string: %r"
 
     def _marshall_from_request(self, value):
         """See `SimpleFieldMarshaller`.
 
         Converts the value to unicode.
         """
-        value = six.text_type(value)
+        value = str(value)
         # multipart/form-data encoding of text fields is required (RFC 2046
         # section 4.1.1) to use CRLF for line breaks.  Normalize to
         # Unix-style LF.
-        value = re.sub(r'\r\n?', '\n', value)
-        return super(TextFieldMarshaller, self)._marshall_from_request(value)
+        value = re.sub(r"\r\n?", "\n", value)
+        return super()._marshall_from_request(value)
 
 
 class FixedVocabularyFieldMarshaller(SimpleFieldMarshaller):
@@ -356,15 +360,15 @@ class FixedVocabularyFieldMarshaller(SimpleFieldMarshaller):
             part of a multiadapter lookup of the appropriate
             marshaller.
         """
-        super(FixedVocabularyFieldMarshaller, self).__init__(field, request)
+        super().__init__(field, request)
 
     def unmarshall_to_closeup(self, entry, value):
         """Describe all values, not just the selected value."""
         unmarshalled = []
         for item in self.field.vocabulary:
-            item_dict = {'token': item.token, 'title': item.title}
+            item_dict = {"token": item.token, "title": item.title}
             if value and value.title == item.title:
-                item_dict['selected'] = True
+                item_dict["selected"] = True
             unmarshalled.append(item_dict)
         return unmarshalled
 
@@ -373,8 +377,7 @@ class TokenizedVocabularyFieldMarshaller(FixedVocabularyFieldMarshaller):
     """A marshaller that looks up value using a token in a vocabulary."""
 
     def __init__(self, field, request, vocabulary):
-        super(TokenizedVocabularyFieldMarshaller, self).__init__(
-            field, request, vocabulary)
+        super().__init__(field, request, vocabulary)
 
     def _marshall_from_json_data(self, value):
         """See `SimpleFieldMarshaller`.
@@ -382,10 +385,9 @@ class TokenizedVocabularyFieldMarshaller(FixedVocabularyFieldMarshaller):
         Looks up the value as a token in the vocabulary.
         """
         try:
-            return self.field.vocabulary.getTermByToken(
-                six.text_type(value)).value
+            return self.field.vocabulary.getTermByToken(str(value)).value
         except LookupError:
-            raise ValueError(u"%r isn't a valid token" % value)
+            raise ValueError("%r isn't a valid token" % value)
 
 
 class DateTimeFieldMarshaller(SimpleFieldMarshaller):
@@ -395,15 +397,31 @@ class DateTimeFieldMarshaller(SimpleFieldMarshaller):
         """Parse the value as a datetime object."""
         try:
             value = DateTimeParser().parse(value)
-            (year, month, day, hours, minutes, secondsAndMicroseconds,
-             timezone) = value
+            (
+                year,
+                month,
+                day,
+                hours,
+                minutes,
+                secondsAndMicroseconds,
+                timezone,
+            ) = value
             seconds = int(secondsAndMicroseconds)
             microseconds = int(
-                round((secondsAndMicroseconds - seconds) * 1000000))
-            if timezone not in ['Z', '+0000', '-0000']:
+                round((secondsAndMicroseconds - seconds) * 1000000)
+            )
+            if timezone not in ["Z", "+0000", "-0000"]:
                 raise ValueError("Time not in UTC.")
-            return datetime(year, month, day, hours, minutes,
-                            seconds, microseconds, pytz.utc)
+            return datetime(
+                year,
+                month,
+                day,
+                hours,
+                minutes,
+                seconds,
+                microseconds,
+                pytz.utc,
+            )
         except DateTimeError:
             raise ValueError("Value doesn't look like a date.")
         except TypeError:
@@ -423,7 +441,7 @@ class DateFieldMarshaller(DateTimeFieldMarshaller):
 
     def _marshall_from_json_data(self, value):
         """Parse the value as a datetime.date object."""
-        super_class = super(DateFieldMarshaller, self)
+        super_class = super()
         date_time = super_class._marshall_from_json_data(value)
         return date_time.date()
 
@@ -434,19 +452,20 @@ class AbstractCollectionFieldMarshaller(SimpleFieldMarshaller):
     It looks up the marshaller for its value-type, to handle its contained
     elements.
     """
+
     # The only valid JSON representation is a list.
     _type = list
-    _type_error_message = 'not a list: %r'
+    _type_error_message = "not a list: %r"
 
     def __init__(self, field, request):
         """See `SimpleFieldMarshaller`.
 
         This also looks for the appropriate marshaller for value_type.
         """
-        super(AbstractCollectionFieldMarshaller, self).__init__(
-            field, request)
+        super().__init__(field, request)
         self.value_marshaller = getMultiAdapter(
-            (field.value_type or Field(), request), IFieldMarshaller)
+            (field.value_type or Field(), request), IFieldMarshaller
+        )
 
     def _marshall_from_json_data(self, value):
         """See `SimpleFieldMarshaller`.
@@ -454,15 +473,14 @@ class AbstractCollectionFieldMarshaller(SimpleFieldMarshaller):
         Marshall every elements of the list using the appropriate
         marshaller.
         """
-        value = super(
-            AbstractCollectionFieldMarshaller,
-            self)._marshall_from_json_data(value)
+        value = super()._marshall_from_json_data(value)
 
         # In AbstractCollection subclasses, _type contains the type object,
         # which can be used as a factory.
         return self._python_collection_factory(
             self.value_marshaller.marshall_from_json_data(item)
-            for item in value)
+            for item in value
+        )
 
     def _marshall_from_request(self, value):
         """See `SimpleFieldMarshaller`.
@@ -477,8 +495,8 @@ class AbstractCollectionFieldMarshaller(SimpleFieldMarshaller):
         if not isinstance(value, list):
             value = [value]
         return self._python_collection_factory(
-            self.value_marshaller.marshall_from_request(item)
-            for item in value)
+            self.value_marshaller.marshall_from_request(item) for item in value
+        )
 
     @property
     def _python_collection_factory(self):
@@ -493,8 +511,12 @@ class AbstractCollectionFieldMarshaller(SimpleFieldMarshaller):
         The collection is unmarshalled into a list and all its items are
         unmarshalled using the appropriate FieldMarshaller.
         """
-        return [self.value_marshaller.unmarshall(entry, item)
-               for item in value]
+        if value is None:
+            return value
+
+        return [
+            self.value_marshaller.unmarshall(entry, item) for item in value
+        ]
 
 
 class SetFieldMarshaller(AbstractCollectionFieldMarshaller):
@@ -511,8 +533,9 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
     It looks up the marshallers for its (key-type, value-type), to handle its
     contained name/value pairs.
     """
+
     _type = dict
-    _type_error_message = 'not a dict: %r'
+    _type_error_message = "not a dict: %r"
 
     def __init__(self, field, request):
         """See `SimpleFieldMarshaller`.
@@ -521,12 +544,13 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
         value_type. If key_type or value_type are not specified, the default
         field marshaller is used.
         """
-        super(DictFieldMarshaller, self).__init__(
-            field, request)
+        super().__init__(field, request)
         self.key_marshaller = getMultiAdapter(
-            (field.key_type or Field(), request), IFieldMarshaller)
+            (field.key_type or Field(), request), IFieldMarshaller
+        )
         self.value_marshaller = getMultiAdapter(
-            (field.value_type or Field(), request), IFieldMarshaller)
+            (field.value_type or Field(), request), IFieldMarshaller
+        )
 
     def _marshall_from_request(self, value):
         """See `IFieldMarshaller`.
@@ -544,14 +568,15 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
             value = [value]
         if isinstance(value, list):
             try:
-                value = dict(nv.split(',', 2) for nv in value)
+                value = dict(nv.split(",", 2) for nv in value)
             except ValueError:
-                raise ValueError(
-                    u"got '%s', list of name,value pairs" % value)
-        return dict(
-            (self.key_marshaller.marshall_from_json_data(key),
-            self.value_marshaller.marshall_from_json_data(val))
-            for key, val in value.items())
+                raise ValueError("got '%s', list of name,value pairs" % value)
+        return {
+            self.key_marshaller.marshall_from_json_data(
+                key
+            ): self.value_marshaller.marshall_from_json_data(val)
+            for key, val in value.items()
+        }
 
     def _marshall_from_json_data(self, value):
         """See `SimpleFieldMarshaller`.
@@ -565,12 +590,13 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
         if isinstance(value, list):
             value = dict(value)
         # Call super to check for errors and raise a ValueError if necessary.
-        value = super(
-            DictFieldMarshaller, self)._marshall_from_json_data(value)
-        return dict(
-            (self.key_marshaller.marshall_from_json_data(key),
-            self.value_marshaller.marshall_from_json_data(val))
-            for key, val in value.items())
+        value = super()._marshall_from_json_data(value)
+        return {
+            self.key_marshaller.marshall_from_json_data(
+                key
+            ): self.value_marshaller.marshall_from_json_data(val)
+            for key, val in value.items()
+        }
 
     def unmarshall(self, entry, value):
         """See `SimpleFieldMarshaller`.
@@ -583,9 +609,12 @@ class DictFieldMarshaller(SimpleFieldMarshaller):
         # Use an ordered dict so that fields using this marshaller have a
         # stable ETag.
         return OrderedDict(
-            (self.key_marshaller.unmarshall(entry, key),
-            self.value_marshaller.unmarshall(entry, val))
-               for key, val in value.items())
+            (
+                self.key_marshaller.unmarshall(entry, key),
+                self.value_marshaller.unmarshall(entry, val),
+            )
+            for key, val in value.items()
+        )
 
 
 @implementer(IUnmarshallingDoesntNeedValue)
@@ -605,8 +634,10 @@ class CollectionFieldMarshaller(SimpleFieldMarshaller):
 
         This returns a link to the scoped collection.
         """
-        return "%s/%s" % (absoluteURL(entry.context, self.request),
-                          self.field.__name__)
+        return "%s/%s" % (
+            absoluteURL(entry.context, self.request),
+            self.field.__name__,
+        )
 
 
 def VocabularyLookupFieldMarshaller(field, request):
@@ -616,8 +647,9 @@ def VocabularyLookupFieldMarshaller(field, request):
     for a marshaller, one that can take into account the vocabulary
     in addition to the field type (presumably Choice) and the request.
     """
-    return getMultiAdapter((field, request, field.vocabulary),
-                           IFieldMarshaller)
+    return getMultiAdapter(
+        (field, request, field.vocabulary), IFieldMarshaller
+    )
 
 
 class SimpleVocabularyLookupFieldMarshaller(FixedVocabularyFieldMarshaller):
@@ -625,8 +657,7 @@ class SimpleVocabularyLookupFieldMarshaller(FixedVocabularyFieldMarshaller):
 
     def __init__(self, field, request, vocabulary):
         """Initialize the marshaller with the vocabulary it'll use."""
-        super(SimpleVocabularyLookupFieldMarshaller, self).__init__(
-            field, request, vocabulary)
+        super().__init__(field, request, vocabulary)
         self.vocabulary = vocabulary
 
     def _marshall_from_json_data(self, value):
@@ -637,8 +668,9 @@ class SimpleVocabularyLookupFieldMarshaller(FixedVocabularyFieldMarshaller):
                 return item
             valid_titles.append(item.title)
         raise ValueError(
-            u'Invalid value "%s". Acceptable values are: %s' %
-             (value, ', '.join(valid_titles)))
+            'Invalid value "%s". Acceptable values are: %s'
+            % (value, ", ".join(valid_titles))
+        )
 
     def unmarshall(self, entry, value):
         if value is None:
@@ -646,8 +678,9 @@ class SimpleVocabularyLookupFieldMarshaller(FixedVocabularyFieldMarshaller):
         return value.title
 
 
-class ObjectLookupFieldMarshaller(SimpleFieldMarshaller,
-                                  URLDereferencingMixin):
+class ObjectLookupFieldMarshaller(
+    SimpleFieldMarshaller, URLDereferencingMixin
+):
     """A marshaller that turns URLs into data model objects.
 
     This marshaller can be used with a IChoice field (initialized
@@ -655,7 +688,7 @@ class ObjectLookupFieldMarshaller(SimpleFieldMarshaller,
     """
 
     def __init__(self, field, request, vocabulary=None):
-        super(ObjectLookupFieldMarshaller, self).__init__(field, request)
+        super().__init__(field, request)
         self.vocabulary = vocabulary
 
     @property
