@@ -2,9 +2,6 @@
 
 """ZCML registration directives for the LAZR webservice framework."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = []
 
 
@@ -16,7 +13,7 @@ from zope.component import (
     adapter,
     getGlobalSiteManager,
     getUtility,
-    )
+)
 from zope.component.zcml import handler
 from zope.configuration.fields import GlobalObject
 from zope.interface import Interface
@@ -33,7 +30,7 @@ from lazr.restful.declarations import (
     generate_entry_adapters,
     generate_entry_interfaces,
     generate_operation_adapter,
-    )
+)
 from lazr.restful.error import WebServiceExceptionView
 
 from lazr.restful.interfaces import (
@@ -47,13 +44,13 @@ from lazr.restful.interfaces import (
     IWebServiceClientRequest,
     IWebServiceConfiguration,
     IWebServiceVersion,
-    )
+)
 
 from lazr.restful.utils import VersionedObject
 
 
 # Keep track of entry and operation registrations so we can
-# sanity-check them later.
+# coherence-check them later.
 REGISTERED_ENTRIES = []
 REGISTERED_OPERATIONS = []
 
@@ -67,6 +64,7 @@ def reset_globals():
     del REGISTERED_OPERATIONS[:]
     REGISTERED_CONTRIBUTORS.clear()
 
+
 try:
     from zope.testing.cleanup import addCleanUp
 except ImportError:
@@ -76,19 +74,23 @@ else:
 
 
 class IRegisterDirective(Interface):
-    """Directive to hook up webservice based on the declarations in a module.
     """
+    Directive to hook up webservice based on the declarations in a module.
+    """
+
     module = GlobalObject(
-        title=u'Module which will be inspected for webservice declarations')
+        title="Module which will be inspected for webservice declarations"
+    )
 
 
 def contribute_to_interface(interface, info):
     tag = interface.getTaggedValue(LAZR_WEBSERVICE_EXPORTED)
-    for iface in tag['contributes_to']:
+    for iface in tag["contributes_to"]:
         if iface.queryTaggedValue(LAZR_WEBSERVICE_EXPORTED) is None:
             raise AttemptToContributeToNonExportedInterface(
                 "Interface %s contributes to %s, which is not "
-                "exported." % (interface.__name__, iface.__name__))
+                "exported." % (interface.__name__, iface.__name__)
+            )
 
         # Check that no names conflict with the extended interface or
         # its contributors.
@@ -121,28 +123,33 @@ def generate_and_register_entry_adapters(interface, info, repository=None):
 
     # Generate an interface and an adapter for every version.
     web_interfaces = generate_entry_interfaces(
-        interface, contributors, *versions)
+        interface, contributors, *versions
+    )
     web_factories = generate_entry_adapters(
-        interface, contributors, web_interfaces)
-    for index, (interface_version, web_interface) in (
-        enumerate(web_interfaces)):
+        interface, contributors, web_interfaces
+    )
+    for index, (interface_version, web_interface) in enumerate(web_interfaces):
         factory_version, factory = web_factories[index]
-        assert factory_version==interface_version, (
+        assert factory_version == interface_version, (
             "Generated interface and factory versions don't match up! "
-            '%s vs. %s' % (factory_version, interface_version))
+            "%s vs. %s" % (factory_version, interface_version)
+        )
 
         # If this is the earliest version, register against a generic
         # request interface rather than a version-specific one.  This
         # will make certain tests require less setup.
         if interface_version == versions[0]:
             interface_version = None
-        register_adapter_for_version(factory, interface, interface_version,
-                                     IEntry, '', info)
+        register_adapter_for_version(
+            factory, interface, interface_version, IEntry, "", info
+        )
 
         # If we were given a repository, add the interface and version
         # to it.
         if repository is not None:
-            repository.append(VersionedObject(interface_version, web_interface))
+            repository.append(
+                VersionedObject(interface_version, web_interface)
+            )
 
 
 def ensure_correct_version_ordering(name, version_list):
@@ -181,13 +188,16 @@ def ensure_correct_version_ordering(name, version_list):
     if sorted_version_list != version_list:
         bad_versions = '", "'.join(version_list)
         good_versions = '", "'.join(sorted_version_list)
-        msg = ('Annotations on "%s" put an earlier version on top of a '
-               'later version: "%s". The correct order is: "%s".')
+        msg = (
+            'Annotations on "%s" put an earlier version on top of a '
+            'later version: "%s". The correct order is: "%s".'
+        )
         raise AssertionError(msg % (name, bad_versions, good_versions))
 
 
-def register_adapter_for_version(factory, interface, version_name,
-                                 provides, name, info):
+def register_adapter_for_version(
+    factory, interface, version_name, provides, name, info
+):
     """A version-aware wrapper for the registerAdapter operation.
 
     During web service generation we often need to register an adapter
@@ -216,8 +226,9 @@ def register_adapter_for_version(factory, interface, version_name,
         # just a random string.
         marker = getUtility(IWebServiceVersion, name=version_name)
 
-    handler('registerAdapter', factory, (interface, marker),
-            provides, name, info)
+    handler(
+        "registerAdapter", factory, (interface, marker), provides, name, info
+    )
 
 
 def _is_exported_interface(member):
@@ -225,14 +236,16 @@ def _is_exported_interface(member):
 
     Returns True if member is a webservice-aware Exception or interface.
     """
-    if (inspect.isclass(member) and
-        issubclass(member, Exception) and
-        getattr(member, '__lazr_webservice_error__', None) is not None):
+    if (
+        inspect.isclass(member)
+        and issubclass(member, Exception)
+        and getattr(member, "__lazr_webservice_error__", None) is not None
+    ):
         # This is a webservice-aware Exception.
         return True
     if IInterface.providedBy(member):
         tag = member.queryTaggedValue(LAZR_WEBSERVICE_EXPORTED)
-        if tag is not None and tag['type'] in [ENTRY_TYPE, COLLECTION_TYPE]:
+        if tag is not None and tag["type"] in [ENTRY_TYPE, COLLECTION_TYPE]:
             # This is a webservice-aware interface.
             return True
     return False
@@ -247,12 +260,22 @@ def find_exported_interfaces(module):
     """
     try:
         module_all = set(module.__all__)
-        is_exported_name = lambda name: name in module_all
+
+        def is_exported_name(name):
+            return name in module_all
+
     except AttributeError:
-        is_exported_name = lambda name: not name.startswith('_')
-    return (interface for name, interface
-            in inspect.getmembers(module, _is_exported_interface)
-            if is_exported_name(name))
+
+        def is_exported_name(name):
+            return not name.startswith("_")
+
+    return (
+        interface
+        for name, interface in inspect.getmembers(
+            module, _is_exported_interface
+        )
+        if is_exported_name(name)
+    )
 
 
 class ConflictInContributingInterfaces(Exception):
@@ -263,7 +286,8 @@ class ConflictInContributingInterfaces(Exception):
     def __init__(self, name, interfaces):
         self.msg = (
             "'%s' is exported in more than one contributing interface: %s"
-            % (name, ", ".join(i.__name__ for i in interfaces)))
+            % (name, ", ".join(i.__name__ for i in interfaces))
+        )
 
     def __str__(self):
         return self.msg
@@ -281,8 +305,9 @@ def register_webservice(context, module):
     the web service.
     """
     if not inspect.ismodule(module):
-        raise TypeError("module attribute must be a module: %s, %s" %
-                        module, type(module))
+        raise TypeError(
+            "module attribute must be a module: %s, %s" % module, type(module)
+        )
 
     for interface in find_exported_interfaces(module):
         if issubclass(interface, Exception):
@@ -290,47 +315,59 @@ def register_webservice(context, module):
             continue
 
         tag = interface.getTaggedValue(LAZR_WEBSERVICE_EXPORTED)
-        if tag['type'] == ENTRY_TYPE:
-            if tag.get('contributes_to'):
+        if tag["type"] == ENTRY_TYPE:
+            if tag.get("contributes_to"):
                 # This isn't a standalone entry, so just register its
                 # contributions in the global map. This has to be done
                 # before entry and operation adapter generation, so we
                 # customise the order.
                 context.action(
-                    discriminator=('webservice entry contributor', interface),
-                        callable=contribute_to_interface,
-                        args=(interface, context.info),
-                        order=1,
-                        )
+                    discriminator=("webservice entry contributor", interface),
+                    callable=contribute_to_interface,
+                    args=(interface, context.info),
+                    order=1,
+                )
             else:
                 context.action(
-                    discriminator=('webservice entry interface', interface),
-                        callable=generate_and_register_entry_adapters,
-                        args=(interface, context.info, REGISTERED_ENTRIES),
-                        order=2,
-                        )
-        elif tag['type'] == COLLECTION_TYPE:
-            for version in tag['collection_default_content'].keys():
+                    discriminator=("webservice entry interface", interface),
+                    callable=generate_and_register_entry_adapters,
+                    args=(interface, context.info, REGISTERED_ENTRIES),
+                    order=2,
+                )
+        elif tag["type"] == COLLECTION_TYPE:
+            for version in tag["collection_default_content"].keys():
                 factory = generate_collection_adapter(interface, version)
                 provides = ICollection
                 context.action(
                     discriminator=(
-                        'webservice versioned adapter', interface, provides,
-                        '', version),
+                        "webservice versioned adapter",
+                        interface,
+                        provides,
+                        "",
+                        version,
+                    ),
                     callable=register_adapter_for_version,
-                    args=(factory, interface, version, provides, '',
-                          context.info),
-                    )
+                    args=(
+                        factory,
+                        interface,
+                        version,
+                        provides,
+                        "",
+                        context.info,
+                    ),
+                )
         else:
-            raise AssertionError('Unknown export type: %s' % tag['type'])
+            raise AssertionError("Unknown export type: %s" % tag["type"])
         context.action(
-            discriminator=('webservice versioned operations', interface),
+            discriminator=("webservice versioned operations", interface),
             args=(context, interface, REGISTERED_OPERATIONS),
             callable=generate_and_register_webservice_operations,
-            order=2)
+            order=2,
+        )
+
 
 @adapter(IProcessStarting)
-def webservice_sanity_checks(registration):
+def webservice_coherence_checks(registration):
     """Ensure the web service contains no references to unpublished objects.
 
     We are worried about fields that link to unpublished objects, and
@@ -344,7 +381,7 @@ def webservice_sanity_checks(registration):
 
     # Create a mapping of marker interfaces to version names.
     versions = getUtility(IWebServiceConfiguration).active_versions
-    version_for_marker = { IWebServiceClientRequest: versions[0] }
+    version_for_marker = {IWebServiceClientRequest: versions[0]}
     for version in versions:
         marker_interface = getUtility(IWebServiceVersion, name=version)
         version_for_marker[marker_interface] = version
@@ -357,12 +394,14 @@ def webservice_sanity_checks(registration):
     available_registrations = set()
     registrations = getGlobalSiteManager().registeredAdapters()
     for registration in registrations:
-        if (not IInterface.providedBy(registration.provided)
-            or not registration.provided.isOrExtends(IEntry)):
+        if not IInterface.providedBy(
+            registration.provided
+        ) or not registration.provided.isOrExtends(IEntry):
             continue
         interface, version_marker = registration.required
-        available_registrations.add(VersionedObject(
-                version_for_marker[version_marker], interface))
+        available_registrations.add(
+            VersionedObject(version_for_marker[version_marker], interface)
+        )
 
     # Check every Reference and CollectionField field in every IEntry
     # interface, making sure that they only reference entries that are
@@ -372,10 +411,18 @@ def webservice_sanity_checks(registration):
             referenced_interface, what = _extract_reference_type(field)
             if referenced_interface is not None:
                 _assert_interface_registered_for_version(
-                    version, referenced_interface, available_registrations,
-                    ("%(interface)s.%(field)s is %(what)s"
-                     % dict(interface=interface.__name__,
-                            field=field.__name__, what=what)))
+                    version,
+                    referenced_interface,
+                    available_registrations,
+                    (
+                        "%(interface)s.%(field)s is %(what)s"
+                        % dict(
+                            interface=interface.__name__,
+                            field=field.__name__,
+                            what=what,
+                        )
+                    ),
+                )
 
     # For every version, check the return value and arguments to every
     # named operation published in that version, making sure that
@@ -383,22 +430,28 @@ def webservice_sanity_checks(registration):
     # version.
     for version, method in REGISTERED_OPERATIONS:
         tags = method.getTaggedValue(LAZR_WEBSERVICE_EXPORTED)
-        return_type = tags.get('return_type')
+        return_type = tags.get("return_type")
         referenced_interface, what = _extract_reference_type(return_type)
         if referenced_interface is not None:
             _assert_interface_registered_for_version(
-                version, referenced_interface, available_registrations,
-                "named operation %s returns %s" % (tags['as'], what))
+                version,
+                referenced_interface,
+                available_registrations,
+                "named operation %s returns %s" % (tags["as"], what),
+            )
 
-        if not 'params' in tags:
+        if "params" not in tags:
             continue
 
-        for name, field in tags['params'].items():
+        for name, field in tags["params"].items():
             referenced_interface, what = _extract_reference_type(field)
             if referenced_interface is not None:
                 _assert_interface_registered_for_version(
-                    version, referenced_interface, available_registrations,
-                    "named operation %s accepts %s" % (tags['as'], what))
+                    version,
+                    referenced_interface,
+                    available_registrations,
+                    "named operation %s accepts %s" % (tags["as"], what),
+                )
     del REGISTERED_OPERATIONS[:]
     del REGISTERED_ENTRIES[:]
 
@@ -406,7 +459,7 @@ def webservice_sanity_checks(registration):
 def _extract_reference_type(field):
     """Determine what kind of object the given field is a reference to.
 
-    This is a helper method used by the sanity checker.
+    This is a helper method used by the coherence checker.
 
     :return: A 2-tuple (reference_type, human_readable): If
     `field` is a reference to a scalar entry, human_readable is
@@ -426,8 +479,9 @@ def _extract_reference_type(field):
 
 
 def _assert_interface_registered_for_version(
-    version, interface, available_registrations, error_message_insert):
-    """A helper method for the sanity checker.
+    version, interface, available_registrations, error_message_insert
+):
+    """A helper method for the coherence checker.
 
     See if the given entry interface is published in the given version
     (as determined by the contents of `available_registrations`), and
@@ -450,13 +504,18 @@ def _assert_interface_registered_for_version(
         raise ValueError(
             "In version %(version)s, %(problem)s, but version %(version)s "
             "of the web service does not publish %(reference)s as "
-            "an entry. (It may not be published at all.)" % dict(
-                version=version, problem=error_message_insert,
-                reference=interface.__name__))
+            "an entry. (It may not be published at all.)"
+            % dict(
+                version=version,
+                problem=error_message_insert,
+                reference=interface.__name__,
+            )
+        )
 
 
 def generate_and_register_webservice_operations(
-        context, interface, repository=None):
+    context, interface, repository=None
+):
     """Create and register adapters for all exported methods.
 
     Different versions of the web service may publish the same
@@ -470,10 +529,12 @@ def generate_and_register_webservice_operations(
         block_mutator_operations_as_of_version = None
     else:
         no_mutator_operations_after = config.active_versions.index(
-            config.last_version_with_mutator_named_operations)
-        if len(config.active_versions) > no_mutator_operations_after+1:
+            config.last_version_with_mutator_named_operations
+        )
+        if len(config.active_versions) > no_mutator_operations_after + 1:
             block_mutator_operations_as_of_version = config.active_versions[
-                no_mutator_operations_after+1]
+                no_mutator_operations_after + 1
+            ]
         else:
             block_mutator_operations_as_of_version = None
     registered_adapters = set()
@@ -485,31 +546,33 @@ def generate_and_register_webservice_operations(
 
     for name, method in methods:
         tag = method.queryTaggedValue(LAZR_WEBSERVICE_EXPORTED)
-        if tag is None or tag['type'] not in OPERATION_TYPES:
+        if tag is None or tag["type"] not in OPERATION_TYPES:
             # This method is not published as a named operation.
             continue
 
-        human_readable_name = interface.__name__ + '.' + method.__name__
-        if (config.require_explicit_versions and tag.stack[0][0] is None):
+        human_readable_name = interface.__name__ + "." + method.__name__
+        if config.require_explicit_versions and tag.stack[0][0] is None:
             # We have annotations for an implicitly defined version, which
             # is prohibited. But don't panic--these might just be the
             # default annotations set by the system. We only need to raise
             # an exception if the method is actually *published*.
             version, annotations = tag.stack[0]
-            if annotations.get('type') != REMOVED_OPERATION_TYPE:
+            if annotations.get("type") != REMOVED_OPERATION_TYPE:
                 version = config.active_versions[0]
                 raise ValueError(
-                    ("%s: Implicitly tagged for export to web service "
-                     'version "%s", but the service configuration requires '
-                     "all version declarations to be explicit. You should "
-                     'add @operation_for_version("%s") to the bottom of the '
-                     'annotation stack.') % (
-                        human_readable_name, version, version))
+                    (
+                        "%s: Implicitly tagged for export to web service "
+                        'version "%s", but the service configuration requires '
+                        "all version declarations to be explicit. You should "
+                        'add @operation_for_version("%s") to the bottom of '
+                        "the annotation stack."
+                    )
+                    % (human_readable_name, version, version)
+                )
 
         # Make sure that this method was annotated with the
         # versions in the right order.
-        ensure_correct_version_ordering(
-            human_readable_name, tag.dict_names)
+        ensure_correct_version_ordering(human_readable_name, tag.dict_names)
 
         operation_name = None
         # If an operation's name does not change between version n and
@@ -528,10 +591,9 @@ def generate_and_register_webservice_operations(
             if version is None:
                 this_version_index = 0
             else:
-                this_version_index = config.active_versions.index(
-                    version)
+                this_version_index = config.active_versions.index(version)
 
-            if tag['type'] == REMOVED_OPERATION_TYPE:
+            if tag["type"] == REMOVED_OPERATION_TYPE:
                 # This operation is not present in this version.
                 # We'll represent this by setting the operation_name
                 # to None. If the operation was not present in the
@@ -558,34 +620,40 @@ def generate_and_register_webservice_operations(
                 # little sloppy, but it's not bad enough to warrant an
                 # exception.)
                 tag_names = list(tag.keys())
-                if tag_names != ['type']:
-                    tag_names.remove('type')
+                if tag_names != ["type"]:
+                    tag_names.remove("type")
                     raise AssertionError(
                         'Method "%s" contains annotations for version "%s", '
-                        'even though it\'s not published in that version. '
-                        'The bad annotations are: "%s".' % (
-                            method.__name__, version,
-                            '", "'.join(sorted(tag_names))))
+                        "even though it's not published in that version. "
+                        'The bad annotations are: "%s".'
+                        % (
+                            method.__name__,
+                            version,
+                            '", "'.join(sorted(tag_names)),
+                        )
+                    )
             else:
-                if tag['type'] == 'read_operation':
+                if tag["type"] == "read_operation":
                     operation_provides = IResourceGETOperation
-                elif tag['type']in ['factory', 'write_operation']:
+                elif tag["type"] in ["factory", "write_operation"]:
                     operation_provides = IResourcePOSTOperation
-                elif tag['type'] in ['destructor']:
+                elif tag["type"] in ["destructor"]:
                     operation_provides = IResourceDELETEOperation
                 else:
                     # We know it's not REMOVED_OPERATION_TYPE, because
                     # that case is handled above.
                     raise AssertionError(
-                        'Unknown operation type: %s' % tag['type'])
+                        "Unknown operation type: %s" % tag["type"]
+                    )
 
-                operation_name = tag.get('as')
-                if tag['type'] in ['destructor']:
-                    operation_name = ''
+                operation_name = tag.get("as")
+                if tag["type"] in ["destructor"]:
+                    operation_name = ""
 
-                if (tag.get('is_mutator', False)
-                    and (no_mutator_operations_after is None
-                         or no_mutator_operations_after < this_version_index)):
+                if tag.get("is_mutator", False) and (
+                    no_mutator_operations_after is None
+                    or no_mutator_operations_after < this_version_index
+                ):
                     # This is a mutator method, and in this version,
                     # mutator methods are not published as named
                     # operations at all. Block any lookup of the named
@@ -602,29 +670,48 @@ def generate_and_register_webservice_operations(
             # version, or if the operation was removed in this
             # version, we need to block lookups of the previous name
             # from working.
-            if (operation_name != previous_operation_name
-                and previous_operation_name is not None):
+            if (
+                operation_name != previous_operation_name
+                and previous_operation_name is not None
+            ):
                 register_adapter_for_version(
-                    _mask_adapter_registration, interface, version,
-                    previous_operation_provides, previous_operation_name,
-                    context.info)
+                    _mask_adapter_registration,
+                    interface,
+                    version,
+                    previous_operation_provides,
+                    previous_operation_name,
+                    context.info,
+                )
                 registered_adapters.add(
-                    (previous_operation_name, version,
-                     previous_operation_provides))
+                    (
+                        previous_operation_name,
+                        version,
+                        previous_operation_provides,
+                    )
+                )
 
             # If the operation exists in this version (ie. its name is
             # not None), register it using this version's name.
             if operation_name is not None:
                 register_adapter_for_version(
-                    factory, interface, version, operation_provides,
-                    operation_name, context.info)
+                    factory,
+                    interface,
+                    version,
+                    operation_provides,
+                    operation_name,
+                    context.info,
+                )
                 registered_adapters.add(
-                    (operation_name, version, operation_provides))
-                if (tag.get('is_mutator')
-                    and block_mutator_operations_as_of_version != None):
+                    (operation_name, version, operation_provides)
+                )
+                if (
+                    tag.get("is_mutator")
+                    and block_mutator_operations_as_of_version is not None
+                ):
                     defined_in = this_version_index
                     blocked_as_of = config.active_versions.index(
-                        block_mutator_operations_as_of_version)
+                        block_mutator_operations_as_of_version
+                    )
                     if defined_in < blocked_as_of:
                         # In this version, this mutator is also a
                         # named operation. But in a later version
@@ -632,9 +719,12 @@ def generate_and_register_webservice_operations(
                         # the operation registration for this mutator
                         # will need to be blocked.
                         block_mutator_operations.add(
-                            (operation_name,
-                             block_mutator_operations_as_of_version,
-                             operation_provides))
+                            (
+                                operation_name,
+                                block_mutator_operations_as_of_version,
+                                operation_provides,
+                            )
+                        )
                 if repository is not None:
                     repository.append(VersionedObject(version, method))
             previous_operation_name = operation_name
@@ -647,8 +737,13 @@ def generate_and_register_webservice_operations(
             # days when mutator operations were also named operations,
             # and it never got de-registered. De-register it now.
             register_adapter_for_version(
-                _mask_adapter_registration, interface, version,
-                operation_provides, operation_name, context.info)
+                _mask_adapter_registration,
+                interface,
+                version,
+                operation_provides,
+                operation_name,
+                context.info,
+            )
 
 
 def _mask_adapter_registration(*args):
@@ -661,16 +756,24 @@ def _mask_adapter_registration(*args):
 
 
 def register_exception_view(context, exception):
-    """Register WebServiceExceptionView to handle exception on the webservice.
+    """
+    Register WebServiceExceptionView to handle exception on the webservice.
     """
     context.action(
         discriminator=(
-            'view', exception, 'index.html', IWebServiceClientRequest,
-            IWebServiceClientRequest),
+            "view",
+            exception,
+            "index.html",
+            IWebServiceClientRequest,
+            IWebServiceClientRequest,
+        ),
         callable=handler,
-        args=('registerAdapter',
-              WebServiceExceptionView, (exception, IWebServiceClientRequest),
-              Interface, 'index.html', context.info),
-        )
-
-
+        args=(
+            "registerAdapter",
+            WebServiceExceptionView,
+            (exception, IWebServiceClientRequest),
+            Interface,
+            "index.html",
+            context.info,
+        ),
+    )
