@@ -6,33 +6,30 @@ This module defines classes that are usually needed for integration
 with the Zope publisher.
 """
 
-from __future__ import absolute_import, division, print_function
-
-__metaclass__ = type
 __all__ = [
-    'browser_request_to_web_service_request',
-    'WebServicePublicationMixin',
-    'WebServiceRequestTraversal',
-    ]
+    "browser_request_to_web_service_request",
+    "WebServicePublicationMixin",
+    "WebServiceRequestTraversal",
+]
 
-
-import simplejson
-from six.moves.urllib.parse import (
+from urllib.parse import (
     quote,
     urlsplit,
     urlunsplit,
-    )
+)
+
+import simplejson
 from zope.component import (
     adapter,
     getMultiAdapter,
     getUtility,
     queryAdapter,
     queryMultiAdapter,
-    )
+)
 from zope.interface import (
     alsoProvides,
     implementer,
-    )
+)
 from zope.interface.interfaces import ComponentLookupError
 from zope.publisher.interfaces import NotFound
 from zope.publisher.interfaces.browser import IBrowserRequest
@@ -45,7 +42,7 @@ from lazr.restful import (
     EntryFieldResource,
     EntryResource,
     ScopedCollection,
-    )
+)
 from lazr.restful.interfaces import (
     IByteStorage,
     ICollection,
@@ -59,7 +56,7 @@ from lazr.restful.interfaces import (
     IWebBrowserInitiatedRequest,
     IWebServiceClientRequest,
     IWebServiceConfiguration,
-    )
+)
 from lazr.restful.utils import tag_request_with_version_name
 
 
@@ -100,12 +97,14 @@ class WebServicePublicationMixin:
                 field = entry.schema.get(name)
                 if ICollectionField.providedBy(field):
                     result = self._traverseToScopedCollection(
-                        request, entry, field, name)
+                        request, entry, field, name
+                    )
                     if result is not None:
                         return result
                 elif IBytes.providedBy(field):
                     return self._traverseToByteStorage(
-                        request, entry, field, name)
+                        request, entry, field, name
+                    )
                 elif IReference.providedBy(field):
                     sub_entry = getattr(entry, name, None)
                     if sub_entry is None:
@@ -117,8 +116,7 @@ class WebServicePublicationMixin:
                 else:
                     # Falls through to our parent version.
                     pass
-        return super(WebServicePublicationMixin, self).traverseName(
-            request, ob, name)
+        return super().traverseName(request, ob, name)
 
     def _traverseToByteStorage(self, request, entry, field, name):
         """Try to traverse to a byte storage resource in entry."""
@@ -165,16 +163,22 @@ class WebServicePublicationMixin:
         appropriate resource.
         """
         try:
-            if (ICollection.providedBy(ob) or
-                queryMultiAdapter((ob, request), ICollection) is not None):
+            if (
+                ICollection.providedBy(ob)
+                or queryMultiAdapter((ob, request), ICollection) is not None
+            ):
                 # Object supports ICollection protocol.
                 resource = CollectionResource(ob, request)
-            elif (IEntry.providedBy(ob) or
-                  queryMultiAdapter((ob, request), IEntry) is not None):
+            elif (
+                IEntry.providedBy(ob)
+                or queryMultiAdapter((ob, request), IEntry) is not None
+            ):
                 # Object supports IEntry protocol.
                 resource = EntryResource(ob, request)
-            elif (IEntryField.providedBy(ob) or
-                  queryAdapter(ob, IEntryField) is not None):
+            elif (
+                IEntryField.providedBy(ob)
+                or queryAdapter(ob, IEntryField) is not None
+            ):
                 # Object supports IEntryField protocol.
                 resource = EntryFieldResource(ob, request)
             elif queryMultiAdapter((ob, request), IHTTPResource) is not None:
@@ -185,9 +189,9 @@ class WebServicePublicationMixin:
                 return ob
             else:
                 # This object should not be published on the web service.
-                raise NotFound(ob, '')
+                raise NotFound(ob, "")
         except ComponentLookupError:
-            raise NotFound(ob, '')
+            raise NotFound(ob, "")
 
         # Wrap the resource in a security proxy.
         return ProxyFactory(resource)
@@ -201,18 +205,20 @@ class WebServicePublicationMixin:
         """
         notifications_provider = INotificationsProvider(request, None)
         notifications = []
-        if (notifications_provider is not None
-            and notifications_provider.notifications):
-            notifications = ([(notification.level, notification.message)
-                 for notification in notifications_provider.notifications])
+        if (
+            notifications_provider is not None
+            and notifications_provider.notifications
+        ):
+            notifications = [
+                (notification.level, notification.message)
+                for notification in notifications_provider.notifications
+            ]
         json_notifications = simplejson.dumps(notifications)
-        request.response.setHeader(
-            'X-Lazr-Notifications', json_notifications)
+        request.response.setHeader("X-Lazr-Notifications", json_notifications)
 
     def callObject(self, request, object):
         """Help web browsers handle redirects correctly."""
-        value = super(
-            WebServicePublicationMixin, self).callObject(request, object)
+        value = super().callObject(request, object)
         self._processNotifications(request)
         if request.response.getStatus() // 100 == 3:
             if IWebBrowserInitiatedRequest.providedBy(request):
@@ -237,25 +243,26 @@ class WebServicePublicationMixin:
                     # characters. Invalid characters may indeed be a
                     # problem, but let the problem be handled
                     # somewhere else.
-                    (scheme, netloc, path, query, fragment) = (
-                        urlsplit(location))
-                    if query == '':
+                    (scheme, netloc, path, query, fragment) = urlsplit(
+                        location
+                    )
+                    if query == "":
                         query = qs_append
                     else:
-                        query += '&' + qs_append
+                        query += "&" + qs_append
                     uri = urlunsplit((scheme, netloc, path, query, fragment))
                     request.response.setHeader("Location", str(uri))
         return value
 
 
 @implementer(IWebServiceClientRequest)
-class WebServiceRequestTraversal(object):
+class WebServiceRequestTraversal:
     """Mixin providing web-service resource wrapping in traversal.
 
     This should be mixed in the request using to the base publication used.
     """
 
-    VERSION_ANNOTATION = 'lazr.restful.version'
+    VERSION_ANNOTATION = "lazr.restful.version"
 
     def traverse(self, ob):
         """See `zope.publisher.interfaces.IPublisherRequest`.
@@ -274,7 +281,7 @@ class WebServiceRequestTraversal(object):
         # was requested and has set the application appropriately, so
         # now we can get a good value for 'ob' and traverse it.
         ob = self.publication.getApplication(self)
-        result = super(WebServiceRequestTraversal, self).traverse(ob)
+        result = super().traverse(ob)
         return self.publication.getResource(self, result)
 
     def _removeVirtualHostTraversals(self):
@@ -302,7 +309,7 @@ class WebServiceRequestTraversal(object):
                     self.setVirtualHostRoot(names=names)
                     break
         if version is None:
-            raise NotFound(self, '', self)
+            raise NotFound(self, "", self)
         tag_request_with_version_name(self, version)
 
         # Find the appropriate service root for this version and set
@@ -335,7 +342,8 @@ class WebServiceRequestTraversal(object):
 @implementer(IWebServiceClientRequest)
 @adapter(IBrowserRequest)
 def browser_request_to_web_service_request(
-    website_request, web_service_version=None):
+    website_request, web_service_version=None
+):
     """An adapter from a browser request to a web service request.
 
     Used to instantiate Resource objects when handling normal web
@@ -349,10 +357,11 @@ def browser_request_to_web_service_request(
     environ = dict(website_request.environment)
     # Zope picks up on SERVER_URL when setting the _app_server attribute
     # of the new request.
-    environ['SERVER_URL'] = website_request.getApplicationURL()
+    environ["SERVER_URL"] = website_request.getApplicationURL()
     web_service_request = config.createRequest(body, environ)
     web_service_request.setVirtualHostRoot(
-        names=[config.path_override, web_service_version])
+        names=[config.path_override, web_service_version]
+    )
     tag_request_with_version_name(web_service_request, web_service_version)
     web_service_request._vh_root = website_request.getVirtualHostRoot()
     return web_service_request
