@@ -2,12 +2,9 @@
 
 """Utilities for dealing with zope security."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'protect_schema',
-    ]
+    "protect_schema",
+]
 
 
 from zope.interface.interfaces import IMethod
@@ -15,8 +12,9 @@ from zope.schema.interfaces import IField
 from zope.security.checker import defineChecker, CheckerPublic, Checker
 
 
-def protect_schema(type_, schema, read_permission=CheckerPublic,
-                   write_permission=None):
+def protect_schema(
+    type_, schema, read_permission=CheckerPublic, write_permission=None
+):
     """Define security checker based on a schema.
 
     This will define a checker for the type, based on the names available in
@@ -44,5 +42,3 @@ def protect_schema(type_, schema, read_permission=CheckerPublic,
                 continue
             write_permissions[name] = write_permission
     defineChecker(type_, Checker(read_permissions, write_permissions))
-
-
