@@ -1,32 +1,32 @@
 """Simple implementations of various Zope and lazr.restful interfaces."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
 __all__ = [
-    'BaseRepresentationCache',
-    'BaseWebServiceConfiguration',
-    'DictionaryBasedRepresentationCache',
-    'IMultiplePathPartLocation',
-    'MultiplePathPartAbsoluteURL',
-    'Publication',
-    'PublicationMixin',
-    'Request',
-    'RootResource',
-    'RootResourceAbsoluteURL',
-    'SimulatedWebsiteRequest',
-    'TraverseWithGet',
-    ]
+    "BaseRepresentationCache",
+    "BaseWebServiceConfiguration",
+    "DictionaryBasedRepresentationCache",
+    "IMultiplePathPartLocation",
+    "MultiplePathPartAbsoluteURL",
+    "Publication",
+    "PublicationMixin",
+    "Request",
+    "RootResource",
+    "RootResourceAbsoluteURL",
+    "SimulatedWebsiteRequest",
+    "TraverseWithGet",
+]
 
 import traceback
-
-import six
-from six.moves.urllib.parse import (
+from urllib.parse import (
     quote,
     unquote,
-    )
+)
+
 from zope.component import (
-    adapter, getMultiAdapter, getUtility, queryMultiAdapter)
+    adapter,
+    getMultiAdapter,
+    getUtility,
+    queryMultiAdapter,
+)
 from zope.interface import Attribute, Interface, implementer
 from zope.publisher.browser import BrowserRequest
 from zope.publisher.interfaces import IPublication, IPublishTraverse, NotFound
@@ -38,8 +38,7 @@ from zope.traversing.browser.absoluteurl import _insufficientContext, _safe
 
 import grokcore.component
 
-from lazr.restful import (
-    EntryAdapterUtility, HTTPResource, ServiceRootResource)
+from lazr.restful import EntryAdapterUtility, HTTPResource, ServiceRootResource
 from lazr.restful.interfaces import (
     IRepresentationCache,
     IServiceRootResource,
@@ -48,19 +47,19 @@ from lazr.restful.interfaces import (
     IWebBrowserOriginatingRequest,
     IWebServiceConfiguration,
     IWebServiceLayer,
-    )
+)
 from lazr.restful.publisher import (
     WebServicePublicationMixin,
     WebServiceRequestTraversal,
-    )
+)
 from lazr.restful.utils import (
     implement_from_dict,
     tag_request_with_version_name,
-    )
+)
 
 
 @implementer(IPublication)
-class PublicationMixin(object):
+class PublicationMixin:
     """A very simple implementation of `IPublication`.
 
     The object passed to the constructor is returned by getApplication().
@@ -96,7 +95,7 @@ class PublicationMixin(object):
         # This should really live in zope.publisher, we are copying because
         # we don't want to depend on zope.app stuff.
         # Namespace support was dropped.
-        if name == '.':
+        if name == ".":
             return ob
 
         if IPublishTraverse.providedBy(ob):
@@ -104,7 +103,8 @@ class PublicationMixin(object):
         else:
             # self is marker.
             adapter = queryMultiAdapter(
-                (ob, request), IPublishTraverse, default=self)
+                (ob, request), IPublishTraverse, default=self
+            )
             if adapter is not self:
                 ob2 = adapter.publishTraverse(request, name)
             else:
@@ -133,7 +133,7 @@ class PublicationMixin(object):
         # Reproduce the behavior of ZopePublication by looking up a view
         # for this exception.
         exception = exc_info[1]
-        view = queryMultiAdapter((exception, request), name='index.html')
+        view = queryMultiAdapter((exception, request), name="index.html")
         if view is not None:
             request.response.reset()
             request.response.setResult(view())
@@ -151,11 +151,12 @@ class Publication(WebServicePublicationMixin, PublicationMixin):
     Combines the IPublication implementation of PublicationMixin
     with the web service implementation of WebServicePublicationMixin,
     """
+
     pass
 
 
 @implementer(ITraverseWithGet)
-class TraverseWithGet(object):
+class TraverseWithGet:
     """An implementation of `IPublishTraverse` that uses the get() method.
 
     This is a simple traversal technique that works with any object
@@ -204,6 +205,7 @@ class RootResource(ServiceRootResource, TraverseWithGet):
     ServiceRootResource expects top-level objects to be registered as
     Zope interfaces.
     """
+
     grokcore.component.provides(IServiceRootResource)
 
     @property
@@ -218,15 +220,18 @@ class RootResource(ServiceRootResource, TraverseWithGet):
         """Return a mapping of top-level link names to published objects."""
         top_level_resources = {}
         # First collect the top-level collections.
-        for name, (schema_interface, obj) in (
-            self.top_level_collections.items()):
+        for name, (
+            schema_interface,
+            obj,
+        ) in self.top_level_collections.items():
             adapter = EntryAdapterUtility.forSchemaInterface(
-                schema_interface, self.request)
-            link_name = ("%s_collection_link" % adapter.plural_type)
+                schema_interface, self.request
+            )
+            link_name = "%s_collection_link" % adapter.plural_type
             top_level_resources[link_name] = obj
         # Then collect the top-level entries.
         for name, entry_link in self.top_level_entry_links.items():
-            link_name = ("%s_link" % ITopLevelEntryLink(entry_link).link_name)
+            link_name = "%s_link" % ITopLevelEntryLink(entry_link).link_name
             top_level_resources[link_name] = entry_link
         return top_level_resources
 
@@ -234,8 +239,10 @@ class RootResource(ServiceRootResource, TraverseWithGet):
     def top_level_objects(self):
         """Return this web service's top-level objects."""
         objects = {}
-        for name, (schema_interface, obj) in (
-            self.top_level_collections.items()):
+        for name, (
+            schema_interface,
+            obj,
+        ) in self.top_level_collections.items():
             objects[name] = obj
         objects.update(self.top_level_entry_links)
         return objects
@@ -247,17 +254,21 @@ class RootResource(ServiceRootResource, TraverseWithGet):
         :return: A hash mapping a name to a 2-tuple (interface, collection).
         The interface is the kind of thing contained in the collection.
         """
-        if not hasattr(self, '_top_level_collections'):
-            self._top_level_collections, self._top_level_entry_links = (
-                self._build_top_level_objects())
+        if not hasattr(self, "_top_level_collections"):
+            (
+                self._top_level_collections,
+                self._top_level_entry_links,
+            ) = self._build_top_level_objects()
         return self._top_level_collections
 
     @property
     def top_level_entry_links(self):
         """Return this web service's top-level entry links."""
-        if not hasattr(self, '_top_level_entry_links'):
-            self._top_level_collections, self._top_level_entry_links = (
-                self._build_top_level_objects())
+        if not hasattr(self, "_top_level_entry_links"):
+            (
+                self._top_level_collections,
+                self._top_level_entry_links,
+            ) = self._build_top_level_objects()
         return self._top_level_entry_links
 
     def _build_top_level_objects(self):
@@ -283,14 +294,13 @@ class RootResourceAbsoluteURL:
         config = getUtility(IWebServiceConfiguration)
         self.version = request.annotations[request.VERSION_ANNOTATION]
         if config.use_https:
-            self.schema = 'https'
+            self.schema = "https"
         else:
-            self.schema = 'http'
+            self.schema = "http"
         self.hostname = config.hostname
         self.port = config.port
         self.prefix = config.service_root_uri_prefix
 
-
     def __str__(self):
         """Return the part of the URL that contains the hostname.
 
@@ -300,17 +310,27 @@ class RootResourceAbsoluteURL:
         __name__ of the subordinate resource.
         """
         use_default_port = (
-            self.port is None or self.port == 0
-            or (self.schema == 'https' and self.port == 443)
-            or (self.schema == 'http' and self.port == 80))
+            self.port is None
+            or self.port == 0
+            or (self.schema == "https" and self.port == 443)
+            or (self.schema == "http" and self.port == 80)
+        )
 
         if use_default_port:
             return "%s://%s/%s%s" % (
-                self.schema, self.hostname, self.prefix, self.version)
+                self.schema,
+                self.hostname,
+                self.prefix,
+                self.version,
+            )
         else:
             return "%s://%s:%s/%s%s" % (
-                self.schema, self.hostname, self.port, self.prefix,
-                self.version)
+                self.schema,
+                self.hostname,
+                self.port,
+                self.prefix,
+                self.version,
+            )
 
     def __call__(self):
         """Return the URL to the service root resource.
@@ -320,7 +340,7 @@ class RootResourceAbsoluteURL:
         will be able to do relative URL resolution correctly with
         respect to the service root.
         """
-        return str(self) + '/'
+        return str(self) + "/"
 
 
 class IMultiplePathPartLocation(Interface):
@@ -340,7 +360,8 @@ class IMultiplePathPartLocation(Interface):
     __parent__ = Attribute("This object's parent.")
     __path_parts__ = Attribute(
         'The path parts of this object\'s URL. For instance, ["foo", "bar"]'
-        'corresponds to the URL path "foo/bar"')
+        'corresponds to the URL path "foo/bar"'
+    )
 
 
 @implementer(IAbsoluteURL)
@@ -362,27 +383,27 @@ class MultiplePathPartAbsoluteURL:
         self.request = request
 
     def __str__(self):
-        parent = getattr(self.context, '__parent__', None)
+        parent = getattr(self.context, "__parent__", None)
         if parent is None:
             raise TypeError(_insufficientContext)
-        start_url = str(
-            getMultiAdapter((parent, self.request), IAbsoluteURL))
+        start_url = str(getMultiAdapter((parent, self.request), IAbsoluteURL))
 
-        parts = getattr(self.context, '__path_parts__', None)
+        parts = getattr(self.context, "__path_parts__", None)
         if parts is None:
             raise TypeError(_insufficientContext)
-        if (isinstance(parts, six.string_types) or
-                not hasattr(parts, '__iter__')):
+        if isinstance(parts, str) or not hasattr(parts, "__iter__"):
             raise TypeError(
-                "Expected an iterable of strings for __path_parts__.")
+                "Expected an iterable of strings for __path_parts__."
+            )
 
-        escaped_parts = [quote(part.encode('utf-8'), _safe) for part in parts]
+        escaped_parts = [quote(part.encode(), _safe) for part in parts]
         return start_url + "/" + "/".join(escaped_parts)
+
     __call__ = __str__
 
 
 @implementer(IRepresentationCache)
-class BaseRepresentationCache(object):
+class BaseRepresentationCache:
     """A useful base class for representation caches.
 
     When an object is invalidated, all of its representations must be
@@ -464,6 +485,7 @@ class DictionaryBasedRepresentationCache(BaseRepresentationCache):
     algorithm or something similar, you can use that. But this class
     was written for testing.
     """
+
     def __init__(self, use_dict):
         """Constructor.
 
@@ -479,11 +501,12 @@ class DictionaryBasedRepresentationCache(BaseRepresentationCache):
         config = getUtility(IWebServiceConfiguration)
         web_service_request = config.createRequest("", {})
         web_service_request.setVirtualHostRoot(
-            names=[config.path_override, version])
+            names=[config.path_override, version]
+        )
         tag_request_with_version_name(web_service_request, version)
 
         # Use that request to create a versioned URL for the object.
-        value = absoluteURL(obj, web_service_request) + ',' + media_type
+        value = absoluteURL(obj, web_service_request) + "," + media_type
         return value
 
     def get_by_key(self, key, default=None):
@@ -500,6 +523,8 @@ class DictionaryBasedRepresentationCache(BaseRepresentationCache):
 
 
 BaseWebServiceConfiguration = implement_from_dict(
-    "BaseWebServiceConfiguration", IWebServiceConfiguration,
-    {'first_version_with_total_size_link': None}, object)
-
+    "BaseWebServiceConfiguration",
+    IWebServiceConfiguration,
+    {"first_version_with_total_size_link": None},
+    object,
+)
