@@ -26,14 +26,11 @@
 
 """Implementation of the ws: namespace in TALES."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
-
 import operator
 import re
 import simplejson
 import textwrap
+from urllib.parse import quote
 
 from docutils import io
 from docutils.core import Publisher
@@ -41,17 +38,20 @@ from docutils.frontend import OptionParser
 from docutils.nodes import (
     Node,
     SkipNode,
-    )
+)
 from docutils.readers.standalone import Reader as StandaloneReader
 from docutils.utils import new_document
 from docutils.writers.html4css1 import (
     HTMLTranslator,
     Writer as HTMLWriter,
-    )
+)
 from docutils.writers.null import Writer as NullWriter
-from six.moves.urllib.parse import quote
 from zope.component import (
-    adapter, getGlobalSiteManager, getUtility, queryMultiAdapter)
+    adapter,
+    getGlobalSiteManager,
+    getUtility,
+    queryMultiAdapter,
+)
 from zope.interface import implementer
 from zope.interface.interfaces import IInterface
 from zope.schema import getFields
@@ -61,7 +61,7 @@ from zope.schema.interfaces import (
     IDate,
     IDatetime,
     IObject,
-    )
+)
 from zope.security.proxy import removeSecurityProxy
 from zope.publisher.interfaces.browser import IBrowserRequest
 from zope.traversing.browser import absoluteURL
@@ -69,17 +69,34 @@ from zope.traversing.interfaces import IPathAdapter
 from lazr.enum import IEnumeratedType
 
 from lazr.restful import (
-    EntryResource, ResourceJSONEncoder, CollectionResource,
-    EntryAdapterUtility, IObjectLink, RESTUtilityBase)
+    EntryResource,
+    ResourceJSONEncoder,
+    CollectionResource,
+    EntryAdapterUtility,
+    IObjectLink,
+    RESTUtilityBase,
+)
 from lazr.restful._resource import UnknownEntryAdapter
 from lazr.restful.interfaces import (
-    ICollection, ICollectionField, IEntry, IJSONRequestCache,
-    IReference, IResourceDELETEOperation, IResourceGETOperation,
-    IResourceOperation, IResourcePOSTOperation, IScopedCollection,
-    ITopLevelEntryLink, IWebServiceConfiguration,
-    IWebServiceVersion, LAZR_WEBSERVICE_NAME)
-from lazr.restful.utils import (get_current_web_service_request,
-    is_total_size_link_active)
+    ICollection,
+    ICollectionField,
+    IEntry,
+    IJSONRequestCache,
+    IReference,
+    IResourceDELETEOperation,
+    IResourceGETOperation,
+    IResourceOperation,
+    IResourcePOSTOperation,
+    IScopedCollection,
+    ITopLevelEntryLink,
+    IWebServiceConfiguration,
+    IWebServiceVersion,
+    LAZR_WEBSERVICE_NAME,
+)
+from lazr.restful.utils import (
+    get_current_web_service_request,
+    is_total_size_link_active,
+)
 
 
 class _ParseError(Exception):
@@ -91,7 +108,7 @@ class _ParseError(Exception):
 
     def __str__(self):
         if self._linenum is not None:
-            return 'Line %s: %s' % (self._linenum, self._descr)
+            return "Line %s: %s" % (self._linenum, self._descr)
         else:
             return self._descr
 
@@ -118,12 +135,16 @@ class _ErrorAccumulatingReader(StandaloneReader):
 
     def report(self, error):
         try:
-            linenum = int(error['line'])
+            linenum = int(error["line"])
         except ValueError:
             linenum = None
 
-        msg = ''.join([c.astext().encode(self._encoding, self._error_handler)
-                       for c in error])
+        msg = "".join(
+            [
+                c.astext().encode(self._encoding, self._error_handler)
+                for c in error
+            ]
+        )
 
         self._errors.append(_ParseError(msg, linenum))
 
@@ -139,16 +160,19 @@ class _PydocParser:
             _ErrorAccumulatingReader(self.errors),
             writer=self.writer,
             source_class=io.StringInput,
-            destination_class=io.NullOutput)
-        self.publisher.set_components('standalone', 'restructuredtext',
-            'pseudoxml')
-        settings_overrides={
-            'report_level':10000,
-            'halt_level':10000,
-            'warning_stream':None,
-            }
-        self.publisher.process_programmatic_settings(None,
-            settings_overrides, None)
+            destination_class=io.NullOutput,
+        )
+        self.publisher.set_components(
+            "standalone", "restructuredtext", "pseudoxml"
+        )
+        settings_overrides = {
+            "report_level": 10000,
+            "halt_level": 10000,
+            "warning_stream": None,
+        }
+        self.publisher.process_programmatic_settings(
+            None, settings_overrides, None
+        )
         self.publisher.set_destination()
 
     def parse_docstring(self, docstring, errors):
@@ -202,7 +226,7 @@ class _PydocHTMLTranslator(HTMLTranslator):
     def depart_document(self, node):
         pass
 
-    def starttag(self, node, tagname, suffix='\n', **attributes):
+    def starttag(self, node, tagname, suffix="\n", **attributes):
         """
         This modified version of starttag makes a few changes to HTML
         tags, to prevent conflicts.  In particular:
@@ -225,29 +249,32 @@ class _PydocHTMLTranslator(HTMLTranslator):
             for (key, val) in list(attr_dict.items()):
                 # Prefix all CSS classes with "rst-"; and prefix all
                 # names with "rst-" to avoid conflicts.
-                if key.lower() in ('class', 'id', 'name'):
-                    attr_dict[key] = 'rst-%s' % val
-                elif key.lower() in ('classes', 'ids', 'names'):
-                    attr_dict[key] = ['rst-%s' % cls for cls in val]
-                elif key.lower() == 'href':
-                    if attr_dict[key][:1] == '#':
-                        attr_dict[key] = '#rst-%s' % attr_dict[key][1:]
+                if key.lower() in ("class", "id", "name"):
+                    attr_dict[key] = "rst-%s" % val
+                elif key.lower() in ("classes", "ids", "names"):
+                    attr_dict[key] = ["rst-%s" % cls for cls in val]
+                elif key.lower() == "href":
+                    if attr_dict[key][:1] == "#":
+                        attr_dict[key] = "#rst-%s" % attr_dict[key][1:]
                     else:
                         # If it's an external link, open it in a new
                         # page.
-                        attr_dict['target'] = '_top'
+                        attr_dict["target"] = "_top"
 
         # For headings, use class="heading"
-        if re.match(r'^h\d+$', tagname):
-            attributes['class'] = ' '.join(
-                [attributes.get('class', ''), 'heading']).strip()
+        if re.match(r"^h\d+$", tagname):
+            attributes["class"] = " ".join(
+                [attributes.get("class", ""), "heading"]
+            ).strip()
 
         return HTMLTranslator.starttag(
-            self, node, tagname, suffix, **attributes)
+            self, node, tagname, suffix, **attributes
+        )
 
 
 WADL_DOC_TEMPLATE = (
-    '<wadl:doc xmlns="http://www.w3.org/1999/xhtml">\n%s\n</wadl:doc>')
+    '<wadl:doc xmlns="http://www.w3.org/1999/xhtml">\n%s\n</wadl:doc>'
+)
 
 
 def generate_wadl_doc(doc):
@@ -265,11 +292,12 @@ def generate_wadl_doc(doc):
     if len(errors) > 0:
         messages = [str(error) for error in errors]
         raise AssertionError(
-            "Invalid docstring %s:\n %s" % (doc, "\n ".join(messages)))
+            "Invalid docstring %s:\n %s" % (doc, "\n ".join(messages))
+        )
 
     visitor = _PydocHTMLTranslator(parsed)
     parsed.walkabout(visitor)
-    return WADL_DOC_TEMPLATE % ''.join(visitor.body)
+    return WADL_DOC_TEMPLATE % "".join(visitor.body)
 
 
 @implementer(IPathAdapter)
@@ -300,7 +328,7 @@ class WebLayerAPI:
     def is_entry(self):
         """Whether the object is published as an entry."""
         request = get_current_web_service_request()
-        return queryMultiAdapter((self.context, request), IEntry) != None
+        return queryMultiAdapter((self.context, request), IEntry) is not None
 
     @property
     def json(self):
@@ -312,8 +340,10 @@ class WebLayerAPI:
             # Just dump it as JSON+XHTML
             resource = self.context
         return simplejson.dumps(
-            resource, cls=ResourceJSONEncoder,
-            media_type=EntryResource.JSON_TYPE)
+            resource,
+            cls=ResourceJSONEncoder,
+            media_type=EntryResource.JSON_TYPE,
+        )
 
 
 class WadlResourceAPI(RESTUtilityBase):
@@ -336,7 +366,7 @@ class WadlEntryResourceAPI(WadlResourceAPI):
 
     def __init__(self, entry_resource):
         "Initialize with an entry resource."
-        super(WadlEntryResourceAPI, self).__init__(entry_resource)
+        super().__init__(entry_resource)
         self.entry = self.resource.entry
         self.schema = self.entry.schema
 
@@ -344,14 +374,6 @@ class WadlEntryResourceAPI(WadlResourceAPI):
     def type_link(self):
         return self.resource.type_url
 
-    @property
-    def fields_with_values(self):
-        """Return all of this entry's Field objects."""
-        fields = []
-        for name, field in getFieldsInOrder(self.schema):
-            fields.append({'field' : field, 'value': "foo"})
-        return fields
-
 
 class WadlCollectionResourceAPI(WadlResourceAPI):
     "Namespace for WADL functions that operate on collection resources."
@@ -367,16 +389,21 @@ class WadlCollectionResourceAPI(WadlResourceAPI):
             # Check whether the field has been exported with a different name
             # and use that if so.
             webservice_tag = self.context.relationship.queryTaggedValue(
-                'lazr.webservice.exported')
+                "lazr.webservice.exported"
+            )
             if webservice_tag is not None:
-                relationship_name = webservice_tag['as']
+                relationship_name = webservice_tag["as"]
             else:
                 relationship_name = self.context.relationship.__name__
-            return (absoluteURL(self.context.context,
-                                get_current_web_service_request()) + '/' +
-                    quote(relationship_name))
+            return (
+                absoluteURL(
+                    self.context.context, get_current_web_service_request()
+                )
+                + "/"
+                + quote(relationship_name)
+            )
         else:
-            return super(WadlCollectionResourceAPI, self).url
+            return super().url
 
     @property
     def type_link(self):
@@ -441,11 +468,16 @@ class WadlServiceRootResourceAPI(RESTUtilityBase):
             else:
                 # It's a collection resource.
                 resource = CollectionResource(
-                    publication, self.resource.request)
-            resource_dicts.append({'name' : link_name,
-                                   'path' : "$['%s']" % link_name,
-                                   'resource' : resource})
-        return sorted(resource_dicts, key=operator.itemgetter('name'))
+                    publication, self.resource.request
+                )
+            resource_dicts.append(
+                {
+                    "name": link_name,
+                    "path": "$['%s']" % link_name,
+                    "resource": resource,
+                }
+            )
+        return sorted(resource_dicts, key=operator.itemgetter("name"))
 
 
 class WadlResourceAdapterAPI(RESTUtilityBase):
@@ -465,19 +497,23 @@ class WadlResourceAdapterAPI(RESTUtilityBase):
     def _model_class(self):
         """Return the underlying data model class for this resource."""
         registrations = [
-            reg for reg in getGlobalSiteManager().registeredAdapters()
-            if (IInterface.providedBy(reg.provided)
+            reg
+            for reg in getGlobalSiteManager().registeredAdapters()
+            if (
+                IInterface.providedBy(reg.provided)
                 and reg.provided.isOrExtends(self.adapter_interface)
-                and reg.factory == self.adapter)]
+                and reg.factory == self.adapter
+            )
+        ]
         # If there's more than one model class (because the 'adapter' was
         # registered to adapt more than one model class to ICollection or
         # IEntry), we don't know which model class to search for named
         # operations. Treat this as an error.
         if len(registrations) != 1:
             raise AssertionError(
-                "There must be one (and only one) adapter from %s to %s." % (
-                    self.adapter.__name__,
-                    self.adapter_interface.__name__))
+                "There must be one (and only one) adapter from %s to %s."
+                % (self.adapter.__name__, self.adapter_interface.__name__)
+            )
         return registrations[0].required[0]
 
     @property
@@ -496,17 +532,24 @@ class WadlResourceAdapterAPI(RESTUtilityBase):
         model_class = self._model_class
         operations = []
         request_interface = getUtility(
-            IWebServiceVersion, get_current_web_service_request().version)
+            IWebServiceVersion, get_current_web_service_request().version
+        )
         for interface in (IResourceGETOperation, IResourcePOSTOperation):
-            operations.extend(getGlobalSiteManager().adapters.lookupAll(
-                    (model_class, request_interface), interface))
+            operations.extend(
+                getGlobalSiteManager().adapters.lookupAll(
+                    (model_class, request_interface), interface
+                )
+            )
 
         # An operation that was present in an earlier version but was
         # removed in the current version will show up in this list as
         # a stub function that returns None. Since we don't want that
         # operation to show up in this version, we'll filter it out.
-        return [{'name' : name, 'op' : op} for name, op in operations
-                if IResourceOperation.implementedBy(op)]
+        return [
+            {"name": name, "op": op}
+            for name, op in operations
+            if IResourceOperation.implementedBy(op)
+        ]
 
 
 class WadlEntryInterfaceAdapterAPI(WadlResourceAdapterAPI):
@@ -514,11 +557,12 @@ class WadlEntryInterfaceAdapterAPI(WadlResourceAdapterAPI):
 
     That is, IEntry subclasses.
     """
+
     def __init__(self, entry_interface):
-        super(WadlEntryInterfaceAdapterAPI, self).__init__(
-            entry_interface, IEntry)
+        super().__init__(entry_interface, IEntry)
         self.utility = EntryAdapterUtility.forEntryInterface(
-            entry_interface, get_current_web_service_request())
+            entry_interface, get_current_web_service_request()
+        )
 
     @property
     def entry_page_representation_link(self):
@@ -534,7 +578,7 @@ class WadlEntryAdapterAPI(WadlResourceAdapterAPI):
     """
 
     def __init__(self, adapter):
-        super(WadlEntryAdapterAPI, self).__init__(adapter, IEntry)
+        super().__init__(adapter, IEntry)
         self.utility = EntryAdapterUtility(adapter)
 
     @property
@@ -555,8 +599,7 @@ class WadlEntryAdapterAPI(WadlResourceAdapterAPI):
     @property
     def patch_representation_link(self):
         """The URL to the description of the object's patch representation."""
-        return "%s#%s-diff" % (
-            self._service_root_url(), self.singular_type)
+        return "%s#%s-diff" % (self._service_root_url(), self.singular_type)
 
     @property
     def entry_page_type(self):
@@ -580,8 +623,10 @@ class WadlEntryAdapterAPI(WadlResourceAdapterAPI):
     @property
     def all_fields(self):
         "Return all schema fields for the object."
-        return [field for name, field in
-                sorted(getFields(self.adapter.schema).items())]
+        return [
+            field
+            for name, field in sorted(getFields(self.adapter.schema).items())
+        ]
 
     @property
     def all_writable_fields(self):
@@ -589,17 +634,21 @@ class WadlEntryAdapterAPI(WadlResourceAdapterAPI):
 
         Read-only fields and collections are excluded.
         """
-        return [field for field in self.all_fields
-                if not (ICollectionField.providedBy(field) or field.readonly)]
+        return [
+            field
+            for field in self.all_fields
+            if not (ICollectionField.providedBy(field) or field.readonly)
+        ]
 
     @property
     def supports_delete(self):
         """Return true if this entry responds to DELETE."""
         request_interface = getUtility(
-            IWebServiceVersion, get_current_web_service_request().version)
+            IWebServiceVersion, get_current_web_service_request().version
+        )
         operations = getGlobalSiteManager().adapters.lookupAll(
-            (self._model_class, request_interface),
-            IResourceDELETEOperation)
+            (self._model_class, request_interface), IResourceDELETEOperation
+        )
         return len(operations) > 0
 
 
@@ -607,19 +656,18 @@ class WadlCollectionAdapterAPI(WadlResourceAdapterAPI):
     "Namespace for WADL functions that operate on collection adapters."
 
     def __init__(self, adapter):
-        super(WadlCollectionAdapterAPI, self).__init__(adapter, ICollection)
+        super().__init__(adapter, ICollection)
 
     @property
     def collection_type(self):
         """The name of this kind of resource."""
         tag = self.entry_schema.queryTaggedValue(LAZR_WEBSERVICE_NAME)
-        return tag['plural']
+        return tag["plural"]
 
     @property
     def type_link(self):
         "The URL to the resource type for the object."
-        return "%s#%s" % (self._service_root_url(),
-                          self.collection_type)
+        return "%s#%s" % (self._service_root_url(), self.collection_type)
 
     @property
     def entry_schema(self):
@@ -638,9 +686,9 @@ class WadlFieldAPI(RESTUtilityBase):
     def required(self):
         """An xsd:bool value for whether or not this field is required."""
         if self.field.required:
-            return 'true'
+            return "true"
         else:
-            return 'false'
+            return "false"
 
     @property
     def name(self):
@@ -654,10 +702,11 @@ class WadlFieldAPI(RESTUtilityBase):
 
         name = self.field.__name__
         if ICollectionField.providedBy(self.field):
-            return name + '_collection_link'
-        elif (IReference.providedBy(self.field)
-              or IBytes.providedBy(self.field)):
-            return name + '_link'
+            return name + "_collection_link"
+        elif IReference.providedBy(self.field) or IBytes.providedBy(
+            self.field
+        ):
+            return name + "_link"
         else:
             return name
 
@@ -675,11 +724,11 @@ class WadlFieldAPI(RESTUtilityBase):
     def type(self):
         """The XSD type of this field."""
         if IDatetime.providedBy(self.field):
-            return 'xsd:dateTime'
+            return "xsd:dateTime"
         elif IDate.providedBy(self.field):
-            return 'xsd:date'
+            return "xsd:date"
         elif IBytes.providedBy(self.field):
-            return 'binary'
+            return "binary"
         else:
             return None
 
@@ -691,10 +740,12 @@ class WadlFieldAPI(RESTUtilityBase):
     @property
     def is_represented_as_link(self):
         """Is this field represented as a link to another resource?"""
-        return (IReference.providedBy(self.field) or
-                ICollectionField.providedBy(self.field) or
-                IBytes.providedBy(self.field) or
-                self.is_link)
+        return (
+            IReference.providedBy(self.field)
+            or ICollectionField.providedBy(self.field)
+            or IBytes.providedBy(self.field)
+            or self.is_link
+        )
 
     @property
     def type_link(self):
@@ -724,23 +775,26 @@ class WadlFieldAPI(RESTUtilityBase):
         """Find an entry adapter for this field."""
         if ICollectionField.providedBy(self.field):
             schema = self.field.value_type.schema
-        elif (IReference.providedBy(self.field)
-              or IObjectLink.providedBy(self.field)):
+        elif IReference.providedBy(self.field) or IObjectLink.providedBy(
+            self.field
+        ):
             schema = self.field.schema
         else:
             raise TypeError("Field is not of a supported type.")
         assert schema is not IObject, (
-            "Null schema provided for %s" % self.field.__name__)
+            "Null schema provided for %s" % self.field.__name__
+        )
         try:
             return EntryAdapterUtility.forSchemaInterface(
-                schema, get_current_web_service_request())
+                schema, get_current_web_service_request()
+            )
         except UnknownEntryAdapter as e:
             e.whence = (
-                'Encountered as a result of the entry interface %r, field %r.'
-                % (self.field.interface, self.field.getName()))
+                "Encountered as a result of the entry interface %r, field %r."
+                % (self.field.interface, self.field.getName())
+            )
             raise e
 
-
     @property
     def options(self):
         """An enumeration of acceptable values for this field.
@@ -748,8 +802,9 @@ class WadlFieldAPI(RESTUtilityBase):
         :return: An iterable of Items if the field implements IChoice
             and its vocabulary implements IEnumeratedType. Otherwise, None.
         """
-        if (IChoice.providedBy(self.field) and
-            IEnumeratedType.providedBy(self.field.vocabulary)):
+        if IChoice.providedBy(self.field) and IEnumeratedType.providedBy(
+            self.field.vocabulary
+        ):
             return self.field.vocabulary.items
         return None
 
@@ -762,8 +817,8 @@ class WadlTopLevelEntryLinkAPI(RESTUtilityBase):
 
     def type_link(self):
         return EntryAdapterUtility.forSchemaInterface(
-            self.entry_link.entry_type,
-            get_current_web_service_request()).type_link
+            self.entry_link.entry_type, get_current_web_service_request()
+        ).type_link
 
 
 class WadlOperationAPI(RESTUtilityBase):
@@ -792,9 +847,9 @@ class WadlOperationAPI(RESTUtilityBase):
         application/x-www-form-urlencoded.
         """
         for param in self.operation.params:
-            if WadlFieldAPI(param).type == 'binary':
-                return 'multipart/form-data'
-        return 'application/x-www-form-urlencoded'
+            if WadlFieldAPI(param).type == "binary":
+                return "multipart/form-data"
+        return "application/x-www-form-urlencoded"
 
     @property
     def is_get(self):
@@ -806,22 +861,23 @@ class WadlOperationAPI(RESTUtilityBase):
         """Human-readable documentation for this operation."""
         docstring = self.operation.__doc__
         # Hack scope information into the docstring for now.
-        scopes = getattr(self.operation, 'scopes', None)
+        scopes = getattr(self.operation, "scopes", None)
         if scopes:
-            docstring += '\n\nScopes: %s\n' % (
-                ', '.join("``%s``" % scope for scope in scopes))
+            docstring += "\n\nScopes: %s\n" % (
+                ", ".join("``%s``" % scope for scope in scopes)
+            )
         return generate_wadl_doc(docstring)
 
     @property
     def has_return_type(self):
         """Does this operation declare a return type?"""
-        return_field = getattr(self.operation, 'return_type', None)
+        return_field = getattr(self.operation, "return_type", None)
         return return_field is not None
 
     @property
     def returns_link(self):
         """Does this operation return a link to an object?"""
-        return_field = getattr(self.operation, 'return_type', None)
+        return_field = getattr(self.operation, "return_type", None)
         if return_field is not None:
             field_adapter = WadlFieldAPI(return_field)
             return field_adapter.is_link
@@ -830,7 +886,7 @@ class WadlOperationAPI(RESTUtilityBase):
     @property
     def return_type_resource_type_link(self):
         """Link to the description of this operation's return value."""
-        return_field = getattr(self.operation, 'return_type', None)
+        return_field = getattr(self.operation, "return_type", None)
         if return_field is not None:
             field_adapter = WadlFieldAPI(return_field)
             try:
@@ -844,7 +900,7 @@ class WadlOperationAPI(RESTUtilityBase):
     @property
     def return_type_representation_link(self):
         """Link to the representation of this operation's return value."""
-        return_field = getattr(self.operation, 'return_type', None)
+        return_field = getattr(self.operation, "return_type", None)
         if return_field is not None:
             field_adapter = WadlFieldAPI(return_field)
             try:
