@@ -1,25 +1,22 @@
-from __future__ import absolute_import, print_function
-
 import sys
 from types import ModuleType
 
-import six
 from zope.configuration import xmlconfig
 from zope.interface import implementer
 
 from lazr.restful.interfaces import IWebServiceConfiguration
-from lazr.restful.metazcml import webservice_sanity_checks
+from lazr.restful.metazcml import webservice_coherence_checks
 from lazr.restful.simple import (
     Request,
     RootResource,
-    )
+)
 from lazr.restful.testing.webservice import WebServiceTestPublication
 
 
 def create_test_module(name, *contents):
     """Defines a new module and adds it to sys.modules."""
     new_module = ModuleType(name)
-    sys.modules['lazr.restful.' + name] = new_module
+    sys.modules["lazr.restful." + name] = new_module
     for object in contents:
         setattr(new_module, object.__name__, object)
     return new_module
@@ -28,17 +25,20 @@ def create_test_module(name, *contents):
 def register_test_module(name, *contents):
     new_module = create_test_module(name, *contents)
     try:
-        xmlconfig.string("""
+        xmlconfig.string(
+            """
             <configure
                 xmlns:webservice=
                     "http://namespaces.canonical.com/webservice">
               <include package="lazr.restful" file="meta.zcml" />
               <webservice:register module="lazr.restful.%s" />
             </configure>
-            """ % name)
-        webservice_sanity_checks(None)
+            """
+            % name
+        )
+        webservice_coherence_checks(None)
     except Exception as e:
-        del sys.modules['lazr.restful.' + name]
+        del sys.modules["lazr.restful." + name]
         raise e
     return new_module
 
@@ -51,10 +51,7 @@ def encode_response(response):
 
     :param response: an httplib HTTPResponse object.
     """
-    response_unicode = str(response)
-    if isinstance(response_unicode, bytes):  # Python 2
-        response_unicode = response_unicode.decode("utf-8")
-    return encode_unicode(response_unicode)
+    return encode_unicode(str(response))
 
 
 def encode_unicode(unicode_string):
@@ -65,7 +62,7 @@ def encode_unicode(unicode_string):
 
     :param unicode_string: A Unicode string.
     """
-    return six.ensure_str(unicode_string.encode("ascii", "backslashreplace"))
+    return unicode_string.encode("ascii", "backslashreplace").decode()
 
 
 @implementer(IWebServiceConfiguration)
@@ -75,11 +72,11 @@ class TestWebServiceConfiguration:
     last_version_with_mutator_named_operations = "1.0"
     code_revision = "1.0b"
     default_batch_size = 50
-    hostname = 'example.com'
+    hostname = "example.com"
     require_explicit_versions = False
 
     def get_request_user(self):
-        return 'A user'
+        return "A user"
 
     def createRequest(self, body_instream, environ):
         request = Request(body_instream, environ)
