@@ -1,15 +1,11 @@
 # Copyright 2008 Canonical Ltd.  All rights reserved.
 """Tests for ETag generation."""
 
-from __future__ import absolute_import, print_function
-
-__metaclass__ = type
-
 from collections import OrderedDict
 from datetime import (
     date,
     datetime,
-    )
+)
 import os.path
 import unittest
 
@@ -26,12 +22,12 @@ from lazr.restful._resource import (
     HTTPResource,
     ServiceRootResource,
     make_entry_etag_cores,
-    )
+)
 
 
 class FunctionalLayer:
     allow_teardown = False
-    zcml = os.path.abspath(resource_filename('lazr.restful', 'ftesting.zcml'))
+    zcml = os.path.abspath(resource_filename("lazr.restful", "ftesting.zcml"))
 
 
 zcml_layer(FunctionalLayer)
@@ -48,92 +44,100 @@ class TestEntryResourceETags(unittest.TestCase):
     def test_no_field_details(self):
         # If make_entry_etag_cores is given no field details (because no
         # fields exist), the resulting cores empty strings.
-        self.assertEqual(make_entry_etag_cores([]), [b'', b''])
+        self.assertEqual(make_entry_etag_cores([]), [b"", b""])
 
     def test_writable_fields(self):
         # If there are writable fields, their values are incorporated into the
         # writable portion of the cores.
         field_details = [
-            ('first_field',
-             {'writable': True,
-              'value': 'first'}),
-            ('second_field',
-             {'writable': True,
-              'value': 'second'}),
-            ]
+            ("first_field", {"writable": True, "value": "first"}),
+            ("second_field", {"writable": True, "value": "second"}),
+        ]
         self.assertEqual(
-            make_entry_etag_cores(field_details), [b'', b'first\0second'])
+            make_entry_etag_cores(field_details), [b"", b"first\0second"]
+        )
 
     def test_unchanging_fields(self):
         # If there are fields that are not writable their values are still
         # reflected in the generated cores because we want and addition or
         # removal of read-only fields to trigger a new ETag.
         field_details = [
-            ('first_field',
-             {'writable': False,
-              'value': 'the value'}),
-            ]
+            ("first_field", {"writable": False, "value": "the value"}),
+        ]
         self.assertEqual(
-            make_entry_etag_cores(field_details),
-            [b'the value', b''])
+            make_entry_etag_cores(field_details), [b"the value", b""]
+        )
 
     def test_combinations_of_fields(self):
         # If there are a combination of writable, changable, and unchanable
         # fields, their values are reflected in the resulting cores.
         field_details = [
-            ('first_writable',
-             {'writable': True,
-              'value': 'first-writable'}),
-            ('second_writable',
-             {'writable': True,
-              'value': 'second-writable'}),
-            ('first_non_writable',
-             {'writable': False,
-              'value': 'first-not-writable'}),
-            ('second_non_writable',
-             {'writable': False,
-              'value': 'second-not-writable'}),
-            ]
+            ("first_writable", {"writable": True, "value": "first-writable"}),
+            (
+                "second_writable",
+                {"writable": True, "value": "second-writable"},
+            ),
+            (
+                "first_non_writable",
+                {"writable": False, "value": "first-not-writable"},
+            ),
+            (
+                "second_non_writable",
+                {"writable": False, "value": "second-not-writable"},
+            ),
+        ]
         self.assertEqual(
             make_entry_etag_cores(field_details),
-            [b'first-not-writable\x00second-not-writable',
-             b'first-writable\x00second-writable'])
+            [
+                b"first-not-writable\x00second-not-writable",
+                b"first-writable\x00second-writable",
+            ],
+        )
 
     def test_collection_fields(self):
         # Field values that are something other than text or bytes are
         # encoded using JSON.
         field_details = [
-            ('list_field',
-             {'writable': False,
-              'value': ['first', 'second']}),
-            ('dict_field',
-             {'writable': False,
-              'value': OrderedDict((('first', 'one'), ('second', 'two')))}),
-            ('date_field',
-             {'writable': False,
-              'value': date(2009, 7, 7)}),
-            ('datetime_field',
-             {'writable': False,
-              'value': datetime(2009, 7, 7, 13, 45, 0, tzinfo=pytz.utc)}),
-            ]
+            ("list_field", {"writable": False, "value": ["first", "second"]}),
+            (
+                "dict_field",
+                {
+                    "writable": False,
+                    "value": OrderedDict(
+                        (("first", "one"), ("second", "two"))
+                    ),
+                },
+            ),
+            ("date_field", {"writable": False, "value": date(2009, 7, 7)}),
+            (
+                "datetime_field",
+                {
+                    "writable": False,
+                    "value": datetime(2009, 7, 7, 13, 45, 0, tzinfo=pytz.utc),
+                },
+            ),
+        ]
         self.assertEqual(
             make_entry_etag_cores(field_details),
-            [b'["first", "second"]\x00{"first": "one", "second": "two"}\x00'
-             b'"2009-07-07"\x00"2009-07-07T13:45:00+00:00"', b''])
+            [
+                b'["first", "second"]\x00{"first": "one", "second": "two"}\x00'
+                b'"2009-07-07"\x00"2009-07-07T13:45:00+00:00"',
+                b"",
+            ],
+        )
 
 
 class TestHTTPResourceETags(unittest.TestCase):
-
     def test_getETag_is_a_noop(self):
-        # The HTTPResource class implements a do-nothing _getETagCores in order to
-        # be conservative (because it's not aware of the nature of all possible
-        # subclasses).
+        # The HTTPResource class implements a do-nothing _getETagCores in
+        # order to be conservative (because it's not aware of the nature of
+        # all possible subclasses).
         self.assertEqual(HTTPResource(None, None)._getETagCores(), None)
 
 
 class FauxEntryField:
     entry = None
-    name = 'field_name'
+    name = "field_name"
     field = None
 
 
@@ -151,10 +155,13 @@ class EntryFieldResourceTests(unittest.TestCase):
         self.resource = EntryFieldResource(FauxEntryField(), None)
 
     def set_field_value(self, value):
-        """Set the value of the fake field the EntryFieldResource references.
         """
-        self.resource._unmarshalled_field_cache['field_name'] = (
-            ('field_name', value), (FauxEntryField(), value, None))
+        Set the value of the fake field the EntryFieldResource references.
+        """
+        self.resource._unmarshalled_field_cache["field_name"] = (
+            ("field_name", value),
+            (FauxEntryField(), value, None),
+        )
         # We have to clear the etag cache for a new value to be generated.
         # XXX benji 2010-09-30 [bug=652459] Does this mean there is an error
         # condition that occurs when something other than applyChanges (which
@@ -164,14 +171,14 @@ class EntryFieldResourceTests(unittest.TestCase):
     def test_cores_change_with_revno(self):
         # The ETag cores should change if the revision (not the version) of
         # the web service change.
-        self.set_field_value('this is the field value')
+        self.set_field_value("this is the field value")
 
         # Find the cores generated with a given revision...
-        self.config.code_revision = u'42'
+        self.config.code_revision = "42"
         first_cores = self.resource._getETagCores(self.resource.JSON_TYPE)
 
         # ...find the cores generated with a different revision.
-        self.config.code_revision = u'99'
+        self.config.code_revision = "99"
         second_cores = self.resource._getETagCores(self.resource.JSON_TYPE)
 
         # The cores should be different.
@@ -184,11 +191,11 @@ class EntryFieldResourceTests(unittest.TestCase):
     def test_cores_change_with_value(self):
         # The ETag cores should change if the value of the field change.
         # Find the cores generated with a given value...
-        self.set_field_value('first value')
+        self.set_field_value("first value")
         first_cores = self.resource._getETagCores(self.resource.JSON_TYPE)
 
         # ...find the cores generated with a different value.
-        self.set_field_value('second value')
+        self.set_field_value("second value")
         second_cores = self.resource._getETagCores(self.resource.JSON_TYPE)
 
         # The cores should be different.
@@ -212,11 +219,11 @@ class ServiceRootResourceTests(unittest.TestCase):
         # web service change.
 
         # Find the cores generated with a given revision...
-        self.config.code_revision = u'42'
+        self.config.code_revision = "42"
         first_cores = self.resource._getETagCores(self.resource.JSON_TYPE)
 
         # ...find the cores generated with a different revision.
-        self.config.code_revision = u'99'
+        self.config.code_revision = "99"
         second_cores = self.resource._getETagCores(self.resource.JSON_TYPE)
 
         # The cores should be different.
@@ -229,12 +236,12 @@ class ServiceRootResourceTests(unittest.TestCase):
         # information.)
 
         # Find the ETag generated with a given revision...
-        self.config.code_revision = u'42'
+        self.config.code_revision = "42"
         first_etag = self.resource.getETag(self.resource.WADL_TYPE)
 
         # ...and find the ETag generated with a different revision.
         self.resource.etags_by_media_type = {}
-        self.config.code_revision = u'99'
+        self.config.code_revision = "99"
         second_etag = self.resource.getETag(self.resource.WADL_TYPE)
 
         # The ETags should be different.
@@ -252,19 +259,18 @@ class TestableHTTPResource(HTTPResource):
 
 
 class TestConditionalGet(unittest.TestCase):
-
     def setUp(self):
         self.config = TestWebServiceConfiguration()
         provideUtility(self.config, IWebServiceConfiguration)
-        self.request = create_web_service_request('/1.0')
+        self.request = create_web_service_request("/1.0")
         self.resource = TestableHTTPResource(None, self.request)
 
     def test_etags_are_the_same(self):
         # If one of the ETags present in an incoming request is the same as
         # the ETag that represents the current object's state, then
         # a conditional GET should return "Not Modified" (304).
-        self.resource.incoming_etags = ['1', '2', '3']
-        self.resource.existing_etag = '2'
+        self.resource.incoming_etags = ["1", "2", "3"]
+        self.resource.existing_etag = "2"
         self.assertEqual(self.resource.handleConditionalGET(), None)
         self.assertEqual(self.request.response.getStatus(), 304)
 
@@ -273,32 +279,31 @@ class TestConditionalGet(unittest.TestCase):
         # the ETag that represents the current object's state, then a
         # conditional GET should result in a new representation of the object
         # being returned.
-        self.resource.incoming_etags = ['1', '2', '3']
-        self.resource.existing_etag = '99'
+        self.resource.incoming_etags = ["1", "2", "3"]
+        self.resource.existing_etag = "99"
         self.assertNotEqual(self.resource.handleConditionalGET(), None)
 
 
 class TestConditionalWrite(unittest.TestCase):
-
     def setUp(self):
         self.config = TestWebServiceConfiguration()
         provideUtility(self.config, IWebServiceConfiguration)
-        self.request = create_web_service_request('/1.0')
+        self.request = create_web_service_request("/1.0")
         self.resource = TestableHTTPResource(None, self.request)
 
     def test_etags_are_the_same(self):
         # If one of the ETags present in an incoming request is the same as
         # the ETag that represents the current object's state, then
         # the write should be applied.
-        self.resource.incoming_etags = ['1', '2', '3']
-        self.resource.existing_etag = '2'
+        self.resource.incoming_etags = ["1", "2", "3"]
+        self.resource.existing_etag = "2"
         self.assertNotEqual(self.resource.handleConditionalWrite(), None)
 
     def test_etags_differ(self):
         # If one of the ETags present in an incoming request is the same as
         # the ETag that represents the current object's state, then
         # the write should fail.
-        self.resource.incoming_etags = ['1', '2', '3']
-        self.resource.existing_etag = '99'
+        self.resource.incoming_etags = ["1", "2", "3"]
+        self.resource.existing_etag = "99"
         self.assertEqual(self.resource.handleConditionalWrite(), None)
         self.assertEqual(self.request.response.getStatus(), 412)
